-- HUMAN RESOURCE MACHINE PROGRAM --
-- 21-Zero-Terminated-Sum - SIZE 10/10 - SPEED 68/72 --

    JUMP     c
a:
    COPYFROM 0
b:
    OUTBOX  
c:
    INBOX   
    JUMPZ    b
d:
    COPYTO   0
    INBOX   
    JUMPZ    a
    ADD      0
    JUMP     d


DEFINE LABEL 0
eJxjZ2Bg0Mrqcl+cExNyqvTHVMbKSyv+VMVsONPzKIKBTBBctOUgiPbqfR7d3ncwr71Pq4e7N2KtV2/I
Kr6equkSHd/TJTpWxFzpPOvJ13PQwauXweHfxGv+FlPWxFtMqcuxnXSu3HbS5GqLKZINkfM3TPi6hmV+
9gaORWvXs8wn102jYBSMAuwAAPDcNx0;

