-- HUMAN RESOURCE MACHINE PROGRAM --
-- 09-Zero-Preservation-Initiative - SIZE 29/5 - SPEED 14/25 --

-- This solution is level-specific (patterned and quantity-limited input).
-- Based on 18.16.specific-Gimlao.asm

    INBOX   
    INBOX   
    OUTBOX  
    INBOX   
    JUMPZ    a
    INBOX   
    INBOX   
    OUTBOX  
    INBOX   
    OUTBOX  
    INBOX   
    JUMPZ    c
    INBOX   
    OUTBOX
    INBOX
a:
    OUTBOX  
    INBOX   
    INBOX   
    OUTBOX  
    INBOX   
    OUTBOX  
    INBOX   
    JUMPZ    c
    INBOX   
    OUTBOX
    INBOX
c:
    OUTBOX  
    INBOX   
    OUTBOX
