-- HUMAN RESOURCE MACHINE PROGRAM --
-- 25-Cumulative-Countdown - SIZE 12/12 - SPEED 79/82 --

-- This solution is superseded by 11.79-skwasjer.asm being functionally same
-- with further optimization.

    JUMP     c
a:
    COPYFROM 1
b:
    OUTBOX  
c:
    INBOX   
    JUMPZ    b
    COPYTO   0
    COPYTO   1
d:
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    JUMP     d


DEFINE LABEL 0
eJxLY2BgWMYg3QCkGAL/8dSD6DhLIe9MK0PfX+YB/o91A/xjNX9HxWp6JripOxW6qe+fE6hhvVRK+/r6
qXrPNsQaHl9306Zwuq2d8WRP+4o2kH47tzeRH9zOVsl6/12g6WO9dLH/ijW7Ao+vC4u4vv5Y1Io1prHe
yxzjzs39F1/RtjReOC8p8mz4R7+EAJDeE1mGvieyIluc8hpnMBScm3ulWGeJX7n3sm913sskmnSW8HYu
mKXfIzJxcm9ky9ve+eWTe9scQfq2zRDyjp1RuRLEjp0BdPOMOxH1s50Kty/IbP21TGax4Mqo5edWbe9q
WP07qmdNX/CidQH+ILUf9yr5hO2/mrl+/7eNYP7WvuCKU/VBIPbxiwH+Cpd0lkRcX7Em8v6OtSCxWWfn
lytcml8OYuddZM6NuO5UOOeuUyGIr335itvye0LeIPbct1td5r6dXx79XmZx9HuVrSCx6PdHXPU/R9gd
+BFhd+3XY/e3f/aGvf3TnvL967qKwo9va1R+be/68dd48v//SXMYRsEooBMAACM2sxw;

DEFINE LABEL 1
eJzzY2Bg2Mtk1QSkGFb9294ForOcyh0EnYp2gdhsjo/d2RzbHG+5WNiUeVvYzPCLsLsQLORtGtoXbBr6
JEszJLE4MfBslb0fT/10t8iWdR7HuncF3pv3KWzFGpD+S8kRdkmJf2rDE5Z3Lo3PWpGUOGP1iawVa2bn
HV8Hkr+bot34Je1PbXLm2xoIf6lzauVSZxBbv+eIa3vLVpctDUxer2vzA69Ueya01xzNcKkTzvvRd6z7
+uT1s69Ptl6qOjlrBd/EGav1WmaslmiqXAnSyzLjihvLjPYUqVnajTdmH+ueOldk4vYFhdPrFzfO8FiW
NC1r5dPenjVnq56ucfQDqb+1+Yjrrc3LOzU2/12wbrvOErlDOktA4hdPPXbXOm29FMTOOfjZw/vYFbeT
D6+4MYyCUTBMAACDE4Uc;

