-- HUMAN RESOURCE MACHINE PROGRAM --
-- 34-Vowel-Incinerator - SIZE 13/13 - SPEED 313/323 --

-- Based on 13.316-FireGoblin.asm

    JUMP     b
a:
    COPYFROM 6
    OUTBOX  
b:
    COPYFROM 5
c:
    COPYTO   9
    INBOX   
    COPYTO   6
d:
    COPYFROM [9]
    JUMPZ    a
    SUB      6
    JUMPZ    c
    BUMPUP   9
    JUMP     d


DEFINE LABEL 9
eJzTY2BgqDMuNN1lssFkh6m3R4HFltQ3llsma1pzLAJKMVSYbjH/bvre+I3la4P9Xpn66wP+2LwLiAn5
6J8Qzu22Jj7WfkOSjtWGJJBa81SOks44jpJ7YQmt88IKJ4pG8S7ljZ2+Zl9S4uZXmY+3xOXN3xRYHLG2
tbx/mXPFyUXOFQfncJa97w8rnN2oldVVapTeVVqZ0l8BMuv2PJ7yfRN5yrt6r9VO6nrcJtz1eVLV5JgN
DhMfb5nT9ngLwygYBaOAKgAAiJVQSw;

