-- HUMAN RESOURCE MACHINE PROGRAM --
-- 08-Tripler-Room - SIZE 21/6 - SPEED 21/24 --

-- This solution is non-input specific

a:
    INBOX   
    COPYTO   0
    ADD      0
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    ADD      0
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    ADD      0
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    ADD      0
    ADD      0
    OUTBOX  
    JUMP      a

