-- HUMAN RESOURCE MACHINE PROGRAM --
-- 26-Small-Divide - SIZE 60/15 - SPEED 47/76 --

-- This solution is level-specific (patterned and quantity-limited input).

    INBOX   
    COPYTO   0
    INBOX   
    COPYTO   1
    COPYFROM 9
    COPYTO   2
    COPYFROM 0
    SUB      1
    JUMPN    a
    COPYTO   0
    BUMPUP   2
    COPYFROM 0
    SUB      1
    JUMPN    a
    COPYTO   0
    BUMPUP   2
    COPYFROM 0
    SUB      1
    JUMPN    a
    COPYTO   0
    BUMPUP   2
    COPYFROM 0
    SUB      1
    JUMPN    a
    COPYTO   0
    BUMPUP   2
a:
    COPYFROM 2
    OUTBOX  
    INBOX   
    COPYTO   0
    INBOX   
    COPYTO   1
    COPYFROM 9
    COPYTO   2
    COPYFROM 0
    SUB      1
    JUMPN    b
    COPYTO   0
    BUMPUP   2
    COPYFROM 0
    SUB      1
    JUMPN    b
    COPYTO   0
    BUMPUP   2
    COPYFROM 0
    SUB      1
    JUMPN    b
    COPYTO   0
    BUMPUP   2
    COPYFROM 0
    SUB      1
    JUMPN    b
    COPYTO   0
    BUMPUP   2
b:
    COPYFROM 2
    OUTBOX  
    COPYFROM 9
    OUTBOX  
    COPYFROM 9
    OUTBOX  


DEFINE LABEL 0
eJwTZmBgyDT6U2ujF1gkpZ1Y/EP9bvVp5WPdB5SSpkkqv52voqKzRFVHZau7vsrW7YYr1mQa6SyRNs5s
VTOZ0aFmIjLRw/z4umCLbxszrUS3MIyCUTAKhhwAABpVHUU;

DEFINE LABEL 1
eJwTZGBgEIlaa5QU+SQrKXLFmrCIGavlo2d09Meuq/gcV1DCmRhYlJcUWFSZXFDyIlW78Uvase7ZaRNm
tqT8XSCa5L1MK+btfIZRMApGwZAFAHlqHpY;

DEFINE LABEL 2
eJzTYmBgeKzLuvmxrsziGyZPsrZbvol8YpsQwO651aXJZ6sLUJqhKaSiLSmxoi05U7txQm5/2Zc8o4KX
uVKxitkB/v2phr5/wzOSZoYtSzMNjWwxDVWexBF5b55pbNaKvKRvG2enqWzVyVHZeiLr20aQWTETuGMm
9+YH1nY7+l1tdvRjbOgL/lb3JnJF/dXM6A7txtruY90dPSITH/YsmLWlQ2dJTXPUct0a72UMo2AUjAKa
AADnT0ip;

DEFINE LABEL 9
eJwzZ2Bg+KGeEBBnGeBfap0fGGcpFVtiHFgkqXxvHrOi9VJmxawVtmadq4DKGJ75SjeYhvLUy0efrfoc
l1i8IeFJVlKiZTxn4pvI5hghby9/Ie/F7lpxdm7CeU9drZqOeIlM/OO/frZ3eNTy5hjRLRsSWDdfSj6+
TjtlxmqQeQwFlSuX5xtPViyeX+5XLhVbXf0msqZZyQckZTjH0PfnvISA+sW/o54s8UzwWKac/2sZT/2v
Zefm3lzsvcxmbtTyjJnWS39OezvfemrjjLrJx7pVJ88vD5r+Oyp2xt6wjJl7wxhGwSgYBQQBANe1W/Y;

