-- HUMAN RESOURCE MACHINE PROGRAM --
-- 34-Vowel-Incinerator - SIZE 94/13 - SPEED 124/323 --

-- This solution is level-specific (patterned and quantity-limited input).

    COPYFROM 1
    SUB      0
    COPYTO   6
    COPYFROM 4
    SUB      3
    COPYTO   7
a:
    INBOX   
    COPYTO   8
    SUB      0
    JUMPZ    a
    SUB      6
    JUMPZ    a
    SUB      6
    JUMPZ    a
    SUB      7
    JUMPZ    a
    SUB      7
    JUMPZ    a
    COPYFROM 8
    OUTBOX  
    INBOX   
    COPYTO   8
    SUB      0
    JUMPZ    a
    SUB      6
    JUMPZ    a
    SUB      6
    JUMPZ    a
    SUB      7
    JUMPZ    a
    SUB      7
    JUMPZ    a
    COPYFROM 8
    OUTBOX  
    INBOX   
    COPYTO   8
    SUB      0
    JUMPZ    a
    SUB      6
    JUMPZ    a
    SUB      6
    JUMPZ    a
    SUB      7
    JUMPZ    a
    SUB      7
    JUMPZ    a
    COPYFROM 8
    OUTBOX  
    INBOX   
    COPYTO   8
    SUB      0
    JUMPZ    a
    SUB      6
    JUMPZ    a
    SUB      6
    JUMPZ    a
    SUB      7
    JUMPZ    a
    SUB      7
    JUMPZ    a
    COPYFROM 8
    OUTBOX  
    INBOX   
    COPYTO   8
    SUB      0
    JUMPZ    a
    SUB      6
    JUMPZ    a
    SUB      6
    JUMPZ    a
    SUB      7
    JUMPZ    a
    SUB      7
    JUMPZ    a
    COPYFROM 8
    OUTBOX  
    INBOX
    INBOX   
    COPYTO   8
    SUB      0
    JUMPZ    a
    SUB      6
    JUMPZ    a
    SUB      6
    JUMPZ    a
    SUB      7
    JUMPZ    a
    SUB      7
    JUMPZ    a
    COPYFROM 8
    OUTBOX  
    INBOX
    INBOX
    OUTBOX  


DEFINE LABEL 6
eJzjZmBgaE4r9Y9MsSypS4pavDvZdunTVNuleg2S04FSDBPqF/osqruVmVr7/z/DKBgFo2DYAQC3GhHJ
;

DEFINE LABEL 7
eJwTYWBguNiyImZvydT51fnn9ujkPz59Kr/m0vnipkdXy8Oe+lWlPrnYInrzSOfMC3d6ZE+k953bw9Zf
t3F737XV77oPzlHr5Jqxpk1y+tTmPzM0a5hWMoyCUTAKhhQAAIkqK6k;

DEFINE LABEL 8
eJzjYWBg0E+KCLyclpuQV/JnxvIm/pNqnWy3gMIMa9q+p0+o76j/Uhi1mDXh46kzge7PGEbBKBgFwwoA
AD9MFMU;
