-- HUMAN RESOURCE MACHINE PROGRAM --
-- 02-Busy-Mail-Room - SIZE 3/3 - SPEED 30/25 --

-- The jump command is introduced. This time inbox and outbox are looped with a
-- jump for automation.

a:
    INBOX   
    OUTBOX  
    JUMP     a

