-- HUMAN RESOURCE MACHINE PROGRAM --
-- 32-Inventory-Report - SIZE 16/16 - SPEED 377/393 --

    JUMP     b
a:
    COPYFROM 15
    OUTBOX  
b:
    INBOX   
    COPYTO   16
    COPYFROM 14
    COPYTO   15
    COPYTO   17
    JUMP     e
c:
    BUMPUP   15
d:
    BUMPUP   17
e:
    COPYFROM [17]
    JUMPZ    a
    SUB      16
    JUMPZ    c
    JUMP     d


DEFINE LABEL 14
eJxzZmBg+CxkmB+qeiSlzup53Bsr2RQzy9+ZbXovOq8pT1n2V955i4Bc+P6FCksPeJkf3+XgprgLqIVB
IPJLO1uGa9XdvDOF7/MN89UK1mZMzZ0Z+zCDK7IzmSvySKxDnGnE78wdwdX16oE9M9UDrZdbBqWtyw09
vut69KeDKSkXjq/MvnC8IK/pWFP+88MgMzdWr824UtvftbrF4XBJy58pD9pDMuM7LySJdvfFL5nwL6py
lmg4SN26nf+itmy4kJS/sivv7NLqevElLT0PF3NMfriYdVHrktpVLMvmbP6wvHW7x9rkvVmbNuy7upVz
n+PO47se77m/jeXQ6dVTj/TMZD56t1vs8JuqVfun5XTuupB0devzOIZRMApGIAAAdXmFYQ;

DEFINE LABEL 15
eJzzYWBg2KunE3xAozXIVdEn5r+MUNpb6YVZjFJvqhilvrRHy9ya5S7HuqhGUX9lqGrRmg7t2lUTrBtm
A7UxaPpZBBb76ATP8shOXe9c0VfpLDMvxMV9qa7HlvWrfJy3MAVN3Do5xHnLzYj9ayOirJdnRR+a5xpj
1u0aE1O2ILorzy2yPJkhdEMkyCy2jKXRnzO/tN/PPjRved7+te/zGTeqFH/bpFTGuLG38u3SqmrjWT9r
vrSvr8sLe9LYXvu5dcESkL6lvTrBuROYy49PmrIse/LsjldTMkquTQvJ7JlRniw973lc8nyTBI4F5clf
Fh4sbl3ycZrmUt71IH1HtuzScd28NsNw67F+ue0y8/R3bF9QtmfBkpL9QYvdz/yZ0n82cRLf+dkdILVx
KywCD+zi9RI59s6BYRSMgmEGAIXThmM;

DEFINE LABEL 16
eJwLZmBgSBAutSgS6crTEFs/+b5I2QmgEIOCEuuiRP3SuRZmM6ZvtRKe+Nfat32CtXiTh1V77R0z5vIz
RjFlWvpvqr5qc7fYa93tvqL2c3GaWt7uCnWTo1+1hU4vNYs/k+7Euc/JWXEXyLzmgE7nHcG3ZkWF3z5q
HB1/Zl6c0OnHqf/2f007vutrmvMWkJpZHptasqJdqwzjYspA/JXZKm6+OWmejIX710YXfzq4uETzeE3F
73NyNQvPG9SynV3dorI6sa1hNkhtQJp4U1U1c/mBeqliEP/GZN/2g7O5WwIWtte2L+QrLV1gm7tu7toM
p1lrM9ym8JWaTfjSPqk/d0J0v/vSrRMnbt04feahOXP6jiQucjgsvmTpAc2lx8Hu3rSZr1R+y/YFv7Zs
WZ+xVfbk5R0tPQd2uVaV7TlTyLb/fXbM8SMpkWcvJB25sDONYRSMgiEIADByk2s;

DEFINE LABEL 17
eJzTZ2BgULRzd7jqFNna4f7/FZDLsMjmlf9DnzRPpiBeryWh33zfhFWFuEU+yV0UMa8yKlyvLjc0pXmF
f0tPsU9F33pn+X6QHrYMAWu2jDdVCVmPlhdl+2/SyFXclVfocPh/8e2jRlW3jzo0Xt7xtWnFxuRmmXkg
9euSXnSyZIs3KVQGVoD4aj3lye/6Tq/2mHjh+KT+iVu9+m7NEu67ke/VJ5QW3b802mzCnnCTyVUh6+a2
BgUsVAz9tMQhjmEUjIJRQDEAABlzUCM;

