-- HUMAN RESOURCE MACHINE PROGRAM --
-- 30-String-Storage-Floor - Size 95/7 - Speed 86/203 --

-- This solution is an exploit discovered by Otto42;
-- the message is known in advance.
-- There are random numbers of X's in the places in the message they occur, so
-- it fast forwards the message to them and uses three jumps to output the
-- correct number of X's.

    COPYFROM 12
    SUB      8
    COPYTO   24
    BUMPDN   24
    COPYFROM 4
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    COPYFROM 15
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 8
    OUTBOX  
    COPYFROM 9
    OUTBOX  
    COPYFROM 0
    OUTBOX  
    COPYFROM 1
    OUTBOX  
    COPYFROM 2
    OUTBOX  
    INBOX   
    INBOX   
    INBOX   
    INBOX   
    INBOX   
    SUB      24
    JUMPN    a3
    JUMPZ    a2
    JUMP     a1
a3:
    COPYFROM 22
    OUTBOX  
a2:
    COPYFROM 22
    OUTBOX  
a1:
    COPYFROM 22
    OUTBOX  
    COPYFROM 17
    OUTBOX  
    COPYFROM 18
    OUTBOX  
    COPYFROM 11
    OUTBOX  
    COPYFROM 12
    OUTBOX  
    COPYFROM 13
    OUTBOX  
    COPYFROM 14
    OUTBOX  
    COPYFROM 15
    OUTBOX  
    INBOX   
    INBOX   
    INBOX   
    SUB      24
    JUMPN    b3
    JUMPZ    b2
    JUMP     b1
b3:
    COPYFROM 22
    OUTBOX  
b2:
    COPYFROM 22
    OUTBOX  
b1:
    COPYFROM 22
    OUTBOX  
    COPYFROM 2
    OUTBOX  
    COPYFROM 13
    OUTBOX  
    COPYFROM 14
    OUTBOX  
    COPYFROM 15
    OUTBOX  
    COPYFROM 4
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    COPYFROM 17
    OUTBOX  
    COPYFROM 18
    OUTBOX  
    INBOX   
    INBOX   
    INBOX   
    INBOX   
    INBOX  
    SUB      24
    JUMPN    c3
    JUMPZ    c2
    JUMP     c1
c3:
    COPYFROM 22
    OUTBOX  
c2:
    COPYFROM 22
    OUTBOX  
c1:
    COPYFROM 22
    OUTBOX  


