-- HUMAN RESOURCE MACHINE PROGRAM --
-- 25-Cumulative-Countdown - SIZE 77/12 - SPEED 68/82 --

-- This solution is level-specific (patterned and quantity-limited input).

    JUMP     c
a:
    COPYFROM 1
b:
    OUTBOX  
c:
    INBOX   
    JUMPZ    b
    COPYTO   0
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    OUTBOX  
    INBOX   
    OUTBOX  
    INBOX   
    JUMPZ    b
    COPYTO   0
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    COPYTO   1
    BUMPDN   0
    JUMPZ    a
    ADD      1
    OUTBOX  


DEFINE LABEL 0
eJxjZ2BguGGSkXTDZHvXIaPzBw4ZdZ0FCjHEWSpqMoyCUTAKhj0AABHoCdo;

DEFINE LABEL 1
eJzTY2BgqNOZXz5FbXrqdZX2lANK7Smu8tvSC6WNCgqlvZr1ZUUmblXMWhGjyLq5XTT79D6h6FNALQzT
zOaX25o92/DebOKeheb3D7Jayh5b6xB96rCTzQk7tw37EjxXrDnidW9etldBCUj9zLDs032hG/b1hX7t
cwiTbhCJepJ1MXpZ2ue4L9miScs7FZKjT+UlTdwzO+3vAt90kYlcmdqNrTnK+ZEFVzP3Fn7Jnlha0Tan
7NzczRUm2zZXbNjHMApGwSigCgAAEp9R0Q;

