-- HUMAN RESOURCE MACHINE PROGRAM --
-- 38-Digit-Exploder - SIZE 28/30 - SPEED 215/165 --

    COMMENT  0
a:
    COPYFROM 9
    COPYTO   0
    COPYTO   1
    INBOX   
    COPYTO   2
    COMMENT  1
b:
    COPYFROM 2
    SUB      11
    JUMPN    c
    COPYTO   2
    BUMPUP   0
    JUMP     b
c:
d:
    COPYFROM 2
    SUB      10
    JUMPN    e
    COPYTO   2
    BUMPUP   1
    JUMP     d
    COMMENT  2
e:
    COPYFROM 0
    JUMPZ    f
    OUTBOX  
    JUMP     g
f:
    COPYFROM 1
    JUMPZ    h
g:
    COPYFROM 1
    OUTBOX  
h:
    COPYFROM 2
    OUTBOX  
    JUMP     a


DEFINE COMMENT 0
eJyTYmBgWCLK6LhEdMUOIJOhRTG6sUVx7oYbij1LLivn9imphdflafqWH9Dyq0jUy+ndrN86f7P+rHUg
tc6W3mXOlm0LQOxZFoI+IDrX841hrmdM036vuRtAfE3ngMq+mIBKhlEwCkbBoAQAIBUhTw;

DEFINE COMMENT 1
eJzTZWBgSNT7Za2q+sv6gRyL8zQpQZ+FYgrh/qIaseFCXqXrBSPqowSb54ULTV4ZJDJ/k6vkhn1WslsO
ailvO1Sosfc4UDvDdcfUjufWqR1vLDO7nS1LJjtb9i51tJq38ZHtyp0d9qt3HXefuELCs3ORhGdOb65n
6/wsrwnLU31mrE3yXbQFpL8t/pd1W3zr/JYECL+3Jr3rTUV61/vyrJ7vJf3Lvpcs2+5ZtnaPY+XmA0Vt
EDtHwSgYBdQBAJNLTP4;

DEFINE COMMENT 2
eJwTZ2BgmCnJ4TZTcsJyIJPhneQfm906f2xA7GlS1llKatZZIHagSXhdoEnNTBD7j7FsKIjutXUv7rUt
n9prm9d/0yGu+aRbYFWuZ2DVfq/wuiTf5nkMo2AUjIJBDwAoIBxa;

DEFINE LABEL 0
eJwzZmBgCBfi8Vwj1DQXyGTQZPlstlDss5mT1B+biTI8np3yugktiqG1LYq5fbcVamb2yE1Ybi89d8NC
sSVb93Mv2QrSE6cf3xKnD2Hv0FUIB9ENTpENd+wjG+7bxbfct5uwvMN+1romx6Xbzrss3abgNnFFqVvh
xJNuJy+cdzlz6Y/x6YsgPQxBSW0MQRv2gZjrA6SCQfTdOAaHu3Erd4LYttExTTXJMU0g9owKv4rrDRqx
55vFApRbwuuk2yH2j4JRMApIAwDQx0n0;

DEFINE LABEL 1
eJxzZmBgCBJhdQkSaZwDZDKUsr83Xi/4zshV8oVej9wLvTrlf3ZlaooR8upm6fLqaZ1ayj1L9BWnrZ4m
NX/TGqGFm/n4Zq0r4OxaDNL738gpP9i4dT6IHWzM7gqiJTydCypcnfKrXFwKG5wSWhucsnquOBVMuOhc
POmgZ/nUPd65fak+kQ2pPjuPZHntO3He5dBpR6uDp0B6nSKts5wiy6eC2DMj/tqC6B0515V25NTNArEv
JFtmMhVaZv4pMksHu71V0Ke0ldnpeNt3y4yuDybhEz6Y/Jv408p/Mpf7j8mSQT8mm6X7T3bKj+qPqM/o
Kpx4pqVtwcnWzkW5HV2LTedC/DAKRsFIAwDvTmTs;

DEFINE LABEL 2
eJxzZWBgmCPx3niOROMcIJMhg+emsqn8LZUS9Q8mB7RYnHfryIby69pk52gFVJapxbd0yhdMmClZPvWH
aMW0nbwV07K4SyaD9LlZGKW4WZRPBbE9zTncQPROH/tcCU/bnCqXuOYql5LJBR6di3I9e5ZkePcsifUv
mBAVEFq7PsA0bT2QXh7cPG9JyOYDQcHbD68P2HlEzn3nkQanbYesbdbuAZl1N04j9m5ccjuI3Rn3xhBE
BxbfVg0sjmkCsUWyFCM8yxQjQOzYvoean6feVZs4667a49mPtHrmfDAxnyPkaztLKvjDNNnQvtkasaZz
9ZNuzHcp1F0QWHV7XnTj49nJ7U4z0jr5etI6GUbBKBhBAADPZmbF;

DEFINE LABEL 9
eJzTYmBgEOb5bvlC+rvlRJk/NusFY5qS+HqXsglOWP5MpnV+o1LTXKASBhHtmKatehH1m/Xdi4V0LDMP
a1pmFmo45ctoxDUf0CqZvEO3cc5aw67FgSZdi0HqnS3tc50tY5reWGb1vLF0LnhlZZKq6WySCpKL97PI
2OljkZHhbZN9xCO+5YhH1fQM7/rZG/1rZq4MKpnsH5LZvSTEu+x3sFP+yiCb7KgAy0yGUTAKRgFNAACf
4j64;

DEFINE LABEL 10
eJxTZmBgeC0l6v9aavZ6IJNBmOer+WXlr+Zlap9MD2h9MgWJsRvk9K42yurxNotv+WQeUjPXPKAyzMit
KE7fvXi3TkyTkE7Pkt06E1ewG8xYO9d81ro3ltPXgPRpOltmajpPWaXmUj+7yD268YhHUDWfr0thvJ9z
wfoA54LQILei38EBlUtCIht+hLTOZxgFo2AU0B0AAJBHNHc;

DEFINE LABEL 11
eJyLZGBgSOV9op3Ka5rGx+dWlMC/YR9QiOGB3DujB3KLtoDYO3ntc73E7XNB7DQdl8I0nQnLd+hOWRVp
OGXVd9O2BW4WMU1uFk75IHlNZ8tMTee2BVUuef0KbsntYl7eZak+XqVsAUHVDEHRjUHBOb3Lg+duAKnN
yQysUkoNrKpJDq9rTMzpbUloW3AjYeHmq4nLtlemrN1TmL5mt1D2jLXR+YUTIwsiGyILDJO58v7Zbc3V
iGXP9y1fW1AyeUVR/7KlxRNXgMwzrI9vaa3vWHi9YcWO6w3zNz2siWnSbszsLmornpTRVTwJpGblxIpp
86ZWTHsxs3Dis1mZ3RNnpXYETUpuXzMhrz98QumU8AnT1yyftGz7vKkb9tnP3HygZf7mA1cXQMKEa21W
j/iKrJ6Spc3zSpZOW523fOFm/tVLtm5eu2gL04b62f83RDeu3sDvvXpDeJ3f5tb5izZPX/Nly9JtDKNg
FAxiAAADVZuv;

