-- HUMAN RESOURCE MACHINE PROGRAM --
-- 41-Sorting-Floor - SIZE 27/34 - SPEED 639/714 --

-- A solution using online insertion sort. It uses
-- the zero terminator to further shorten the program.

    JUMP     d
a:
    COMMENT  1
    COPYFROM [23]
    COPYTO   [21]
    COPYFROM 23
b:
    COPYTO   21
    COMMENT  0
    JUMPZ    c
    BUMPDN   23
    COPYFROM 22
    SUB      [23]
    JUMPN    a
    COMMENT  3
c:
    COPYFROM 22
    COPYTO   [21]
d:
e:
    INBOX   
    JUMPZ    f
    COPYTO   22
    BUMPUP   24
    COPYTO   23
    BUMPDN   23
    JUMP     b
f:
    COMMENT  2
    COPYTO   [24]
    COPYTO   24
    COPYTO   23
g:
    COPYFROM [23]
    JUMPZ    e
    OUTBOX  
    BUMPUP   23
    JUMP     g


DEFINE COMMENT 0
eJxLYmBg2OAnHhjuLzEVyGT4EDjR6UvkTXfBuAofm4SUkEcJ7gmPEowzFsXuK+GM5q7QCIqohqiLqL4W
ur7qSIxAmVp8RLV+0rtmtfi1c4/ELF6YHPVtUWOgxxJ5/2+LHnivnQtSX1oaUf2vMLj2W979TuZc4emn
cz4uscq1W/Et79Gq0tLu1fGN5ZsfN6luetw0YaV6I8vcvjrD7lOVUkV2pc9SNEsepi0tKiwEmXN3SpPH
/8ncFXlT7nf6TM2fIjvj/7xvc4Wng+Q+TQ2uDV66vgrE3rBGKLhtlXGG5UqHVsuVElPFVyXM+rt2/mKh
9R5LPqz3WbRj/f95IHUZy1bVbF0eUf1hPWONxbYtFSCx4n33O9X2Vk4Q3OOzqGHPrKW7j7StZTp9ecOD
0/rrJM7MWmp1OnrOumOG3Wf2JpWf2RtcC9Lz84pOL981lrl8156vcAPSFbcntWXfdW1Of5Q64/VjuxU1
j9vWXntkt6LlWcmkIy+t2z1e93awvFWaaP324NSpb26sYxgFo2CAAAAiTrjF;

DEFINE COMMENT 1
eJzzYWBgMFD7P89Vvblnj9a+kkCj8976xjL+DGY7y5IszDqfWV7o32bj2lzm5p4g7nPPNcW3x0Xev93N
NOC897SgrnTb4J1lrMESU4HGMMTmbKkoz3BtXpfBOVs28/889+xvi3TzZy0VLvZZlFDyf96Mku0zdxW/
a95VfDbvX6FU0cuCpHKQPp2aiGrH2ojqxoaFDUHNLHNv9uwrAYkrTp7eIjDLqzF13voqp/kqed/mXsop
m3646MK0SW32009PtJrzZpnuvI9LQGp3H7nneuLQKd+0Az5xq/adzSvet76qY//L1uqDV3tnHM2fsu3k
6Ykbz5l12l6e3tJ1xb+e8cbG8FPXtT1BekNfvmyVe3lssuizu2tAfMHXOcWxbwTKjn/s6JrwkXM2z4df
C/a/81nU8uxWN8MoGAXDDAAAKlCOIQ;

DEFINE COMMENT 2
eJzzYWBgeK+v6DtJ42HaT9XpLQZqJZNc1VNnKGtEz5ml7bHkrMGElfOMJ6wUNV+80MPGuv2mdU6xveW2
0GVmtV5nDZZaAbUz3A743JgTsH2mRtCspSXBdiv4wp6v8I30WLIoVnby9jjD7u1xDq3FCZUTvidargKp
31jwLKWqoLAwIO/0xPa8wAVz8i1XvSy4sW5X8YSVIHnhYp3e2TXTW0Ds3VMdWt/3xu1d1ON/WLC3aCtI
TGCWQ6v/3INTi+a8WaY17dGqP90Qc7nWXO3VWX2hf/KKxQujV9xds2Jl4/oXa0zWHNy0eOHrLXumn9yq
v27iVogZHfu3hc498DWO52BD9twDgQs2Hexe/f9QzcZ1xzJ23jghtmPKqZNb9p3pXg1SW3Zs+0zVU8cm
t5+RncwwCkbBMAMA7TaOQw;

DEFINE COMMENT 3
eJzzZGBgmK/GaPFYZVvoMYXpLS/kq64AhRi6JY7r8EuVaovLHte5aV2qDRJ7K7VrF5PM6gPJ2lv3JFmw
7zsZvvDItdD3x0FyJ8PP5kWF/6hfHjF/cViMTm9HokDZ3KSdZaJpXo0cGc7LQGrsSoNrvYsZa14WuDa/
LDDs9i5OncFfYbImo1x10/mS8s0gNXoT+WYum1Iy6e2s5p4r8ya1ScyNrdw260TB7qnGGZsnGWdwdq2q
iWoTns7QbrLmXvvJLRc7k3d79K4+cGLytYsg/ec2BC44t2HCyqBNu3ad3Lp44aLdZp0B+yWmguS6rmQG
6Z59lnLhaHBt3mGliUsPr5h/+Hjy7m0nlx36dsb1uOWN2+dB6tbvdG2+emB6y4oblROirx+bzDAKRsEw
BgC+g4TZ;

DEFINE LABEL 21
eJzTZGBgqHIs1a5y9Fjy0lF6G5DL8NJxrnSC61xpcZ/J8gdD/KwPhjx2fhys5q0RdCBwshdz5AzX/1Eg
dRNTThS4JEsVvY/LmtaROH9xdfKElXmpJmu00vXXHc5sW1uUa7nqSv6m2c4FF/rn5C+r25fHXaGa05rZ
krYmEqR/al9X+rOuSzmzOqWKZnWadTp0qfcHTni+4sCEG+se9atuquiq2XivXWELAxng6fS+M4dnPH73
qP/FG7lujxedzd+egcSPrmWOZFy5vurUigv9K1b+WsC15si2o2uZDtxeF3JQf3Pc3vxt+3eIbi/ffHLr
SbC9bauEp99eJzH12uYL/SD+jKO8oWXH+lPZj6WXvjq4dm7agf07Qo5Hzzl9avvMqnO/FjRdrNmocWnX
rmPnFx4hx92jYBTQGwAAEayQsQ;

DEFINE LABEL 22
eJxLZGBg2CS01KpKaE7TBOFjkyOEN+wDCjHYiX+ynaSxygLEDpbgrghSTSoHsTXF4vYuUYzbe1IjYyeI
P8N1h1GC64cEEZdldd/sazaCxCr9Zi2dFhS4oDbs4FTl8Lo+g9CXrSXBL1t3BvZ2zPaVmOrvU7T1q0/y
bie/kIOLA7yOZse+Pw7StzBLvV81J3qOas7zFQuzdu3aWHBw6p0ind7usgv9bhVZ0/grTm6JrrRbUVl7
bHJ4XeUEoYa6vjVNShMNWsLmnWx7s2x5u/S25e0hBxnafxwGmac7T3WT6UK7FbsWBS6Yvnj7zITFxyZ7
L6qc0L9Avf/BHNnJ9bNY5mbO7F69cObqAzGzPx/VnffqZNOiz0dBelk3yk4u2Zg1bfVGsR0/Nh3Zxrul
ZuO9bWHz5HZJTF20W2Lqqn2pM8wOm6wxO6ywxfngwiM8B5+eVjzkBda75nJS+ZrLDq0al/TXaVzav6P0
8uRTrTcfnD3w0Og872Pzs7yPX50EqVM477NI/9H2mQyjYBQMIAAAP8Wxdw;

DEFINE LABEL 23
eJyLZ2BgUFAQMaiU97R9ILMt9IFMV3qwxK3up+Ldq4FSDDHSixdaycxaWik/a2mcwYr5ILEZrnOavF1c
m7/Z/5+3337+4isOj1aJuJzcUuYmtiPGS2xHpd/JLeH+qps2+G2fecqLrQqkpziht0Mt3qzzT8zV3vXR
HkvkYtrWbo8r2no1KXe7UsqRbT5pj1btTpu11Ccta9r/lAv9jxIcWkH6NEuEgktLf9SXlkbP2VUsuGtX
cflmkPiC8uae+MZ3zTWtf2pBfMdand7wOrsVi+vPbeJtfXAWJNa/4HPjkoXbZ+YubFxfNX//Dom5VVdM
F+7f0bV06nKQvOnCm+4gOmfdu2ah9bnb/65dfUB+7YZ90zZ4LGnZbt2etTuimudgXR/PwU2zA/YL7gKp
/XferFP3rHq/+8nFC41O6K/jPym2Q/VU5H7/M15Hq859Ptp0kX1f8JWajfOv/lpw6Ip6/5tr+usKbuzf
sffmysd8134/+XSE677egexbe7afucowCkbBIAAAyuey1Q;

DEFINE LABEL 24
eJzzZ2BgqJTfbFIndSmnW+L/PCCXoVti8cLNJr8WLLT+tijVwXkZSMw04H4nZ/ST9uSoLRUnw1Xy0kO7
0qVDLNL++p8o6PPnrgj3f9Ke4qu/7kPg/h3XQiP3vw6L3A/S9zvTodU9+/RE92zpbQuzZi2VyFvY8K8w
p9i7WLSEv8Ksc2vFptnXy4u2gtQ2T/WvnzD5c2Nxf11fcf/8xd8n3F0TOVlrQ/PUR6vWTV8x32jmwak3
Zj5pj5nd3PNgzsGp3+Z+XPJtrseLZVM23z/Td+YqyIySjXkBH9ar5H1Y/7nRZqNOr+h2lrmS+x+t4jlo
subVQctVegc8loDUha3NKX62U7RE70BhIYifeWJb6LaT20ILT3elfztzY13uhe0zn1xmrMm4KlA26fq+
kue3/esb713tZX0wf/HZ+yZrdtw7t4lhFIyCYQAA9bCcCQ;

