-- HUMAN RESOURCE MACHINE PROGRAM --
-- 08-Tripler-Room - SIZE 22/6 - SPEED 20/24 --

-- This solution is non-input specific. Based on sutch's solution.

    INBOX   
a:
    COPYTO   0
    ADD      0
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    ADD      0
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    ADD      0
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    ADD      0
    ADD      0
    OUTBOX  
    INBOX   
    JUMP     a


