-- HUMAN RESOURCE MACHINE PROGRAM --
-- 32-Inventory-Report - SIZE 30/16 - SPEED 45/393 --

-- This solution is superseded by 20.44.exploit-skwasjer.asm being functionally
-- same with further optimization.

    COMMENT  5
    COPYFROM 14
    COPYTO   19
    BUMPUP   19
    ADD      19
    COPYTO   17
    ADD      19
    COPYTO   18
    ADD      19
    COPYTO   15
    ADD      19
    COPYTO   16
    COMMENT  4
a:
b:
c:
d:
    INBOX   
    SUB      1
    JUMPZ    g
    SUB      19
    JUMPZ    f
    SUB      19
    JUMPZ    e
    COMMENT  3
    COPYFROM 18
    OUTBOX  
    JUMP     a
e:
    COMMENT  2
    COPYFROM 17
    OUTBOX  
    JUMP     d
f:
    COMMENT  1
    COPYFROM 16
    OUTBOX  
    JUMP     c
g:
    COMMENT  0
    COPYFROM 15
    OUTBOX  
    JUMP     b


DEFINE COMMENT 0
eJzjYQCCpPd7u0sLTZ0r+mT2Vs3XWNswPyyig3epQLfSFpD0jIKQGpaKgMrsxoBKhlEwCkbBsAIAGwER
Gw;

DEFINE COMMENT 1
eJyTYWBg4I3dYHIsPlO/JnmxtkjRYu3sRj1jhdbPZnJtldb3Wlmck1sCvN/X5ybsqj6Y51beVTq1MKBy
V7VorVxbZvf0jvf9QV1/ZoR2nlyU3CK6mrFSaUtexprdQGMZFudsMJHPa3OZm8dTLlnwvv96wfQ1DKNg
FIyCQQUA/kUvRA;

DEFINE COMMENT 2
eJwTZmBgEO6a7GtX1eU+o4DHMyczIfxHiln64YSAytOxWj09sT+mesU5z2NKvLWuLPX93pQc+5Pni09e
cK44d/lhy7nLAd0cF7p6D57y6Ks6yjAKRsEoGHIAAFTnJLY;

DEFINE COMMENT 3
eJzjYmBgCI/cYPIj5aSbYPGW1MBFZYeAQgyfp95TF+ssTftfeWnF+eI/xxhGwSgYBcMSAADr+xHP;

DEFINE COMMENT 4
eJwzY2BgmBaZonM7PLP7dvifY1ERbecCi93PA4UZTvYqtgV0l06Z0im44krnvY09PSt2tPTr7TWdumGf
6uwlW+Xnzl5/d67girtz2xYsnv2+/930Ww2fp06uBunN3qDYpr9+SXvxWrOpn9Z2Lc5bL7hCZXPE2lnb
Zq+/suPWuoBdgis492r1dO153Ca2I6RmwRYQnt0I0it9Tq8/6bTzmdRTW98/PhVzL+rcloMcV3mXbr6j
1ZNzP6F12vNLVYEvbzXwv3rcxv+qcGLgy53TxJ8zzDG6672E+8rs9bfPym5kGAWjYBQQBQCG2G/d;

DEFINE COMMENT 5
eJyzY2BgUObjkc5XPCnxWqlPRktZVDFHKUVnm5y1jb20s5ORAodbuoqgT4qqqL+SWkK4klpqlKqqVlyh
wvd0K9m6nJmC3mVAIxiYPU9KtLtzSPS6eksl2z7XfWVVaZ1tddYz22p6gJpNZqy0Q1Wmt9vJEkavkyWv
A6syXwYZpTwLTghfEvLdUjVEz3ijv6TKTp/J8syegnIg8/wX80gHLnquG7iIxZl/MYcb7xJvj8YVAd6P
Ngd4g+RXbxBVzNx4SyVzY25C3vpLVSCxlycmy+85eEtlyxF314yT7q6pp7rcFc6E+CmcWRKpdup7+prj
Rwt/HuqvcNsXUMkwCkbBKAADAGZfV8s;

DEFINE LABEL 14
eJxTZGBgCO20tkluYXDYWsvjeb0gNyEzi6PkQ7pa54b0PzPyMniXquQ83hKX93pXbdXJC0ubQ24c67t0
bdsUlrPrplcdXTlzw755c/uXRc4vnTJz/uTqyPneZQ/mfE/fOG12MFt/l3tug5kl0AqGb1PWGB7p7/O6
0vk+saKma3FDZeo271KGU+KFz58yjIJRMAoGDAAAJ1lBGw;

DEFINE LABEL 15
eJwTYGBgSLP5cTja4d7Gfpe9My1818SvCeTxVAgzs4wJ32ElFcHg0JLwY+qrTNn7QKUMjF5bJm/0N5ok
Efljakla1XQGKoLrBfeab+XzlCvmfk9XzDVKkc/bkCST/zw6sqAwWaQopMavJLePp/TofJDapc2Z+k+a
d1gtamFweNhyrVauTa9frg3inobKk27KLW0uPyZzuIH47MvWxE9clJtwe55RSvzc7+mvZ/RXrJv+vDNn
xppepTmlU64u2DvzxNKmuWVrDs4BqY/YnqkvtsPITGTnNX+RnXU5E3ZxLLqztb8ibqtRytyta+Ilt6dG
deydHWxxeHbwx6MJ4don9BIzTlZlPjy9cxo1w2MUjAJ6AABFI3H9;

DEFINE LABEL 16
eJyTYmBg6Il1d83ManPJbeDxzG4M8F7VGOKX3Zga9aV2bzZLRUDl5KLZjdH5ss3ni5e0L2p53y/XtnPa
vVaW+cot55bmNsxe/79Sa9fVwh+H32Y0neaKO3oWaCTD3Dxvj7l5kkErssymrs4sO8RARbC/cm92dXVX
6dbawolfal/vKq4zPwwSN6yf3WhYf602t+FSlXT7wbyLXXU5J3vtc4/1NeX/mxhSUzTtx9R1088t1Z2x
Yse66YX7QXq4lkoGtS17n8i6PKbJcjVEzHTqihjL1StiQOy9K5dELtiyJJKa7h8Fo2AwAQBENGU7;

DEFINE LABEL 17
eJwTZ2BgmNX+3XJps5FZbZWRmUhRqcWrzL22dUnurjHhihHaQUYpP30CKm29n3f+89o5zdrHe8kWv1vr
kkJ3HmlJCLmxI+XWnZzMe/f5SxY8aK6QvFNa63NpVWPZoSfN8zcxjIJRMAoGPQAAkHEr5g;

DEFINE LABEL 18
eJzjYWBgOBH3xyawOKJ+bcPjLdLtDKeAQgx32v7Y5Db0ebmVb0gSL+Qp35EyeeXEaIjcKBgFo2D4AABh
8hN9;

DEFINE LABEL 19
eJxjZWBgyG78bvm+PjO2oL5wombT4y0Mo2AUjIIRAwDlnQiJ;

