-- HUMAN RESOURCE MACHINE PROGRAM --
-- 28-Three-Sort - SIZE 47/34 - SPEED 75/78 --

    COMMENT  9
    JUMP     e
a:
    COPYFROM 2
    OUTBOX  
    COPYFROM 1
b:
    OUTBOX  
    COPYFROM 0
c:
d:
    OUTBOX  
e:
    INBOX   
    COPYTO   0
    INBOX   
    COPYTO   1
    SUB      0
    JUMPN    j
    COMMENT  0
    INBOX   
    COPYTO   2
    SUB      0
    JUMPN    i
    COMMENT  3
    COPYFROM 0
    OUTBOX  
    COPYFROM 1
    SUB      2
    JUMPN    g
    COMMENT  4
    COPYFROM 2
f:
    OUTBOX  
    COPYFROM 1
    JUMP     d
g:
    COMMENT  5
    COPYFROM 1
h:
    OUTBOX  
    COPYFROM 2
    JUMP     c
i:
    COMMENT  2
    COPYFROM 2
    OUTBOX  
    COPYFROM 0
    JUMP     f
j:
    COMMENT  1
    INBOX   
    COPYTO   2
    SUB      1
    JUMPN    a
    COMMENT  6
    COPYFROM 1
    OUTBOX  
    COPYFROM 0
    SUB      2
    JUMPN    k
    COMMENT  7
    COPYFROM 2
    JUMP     b
k:
    COMMENT  8
    COPYFROM 0
    JUMP     h


DEFINE COMMENT 0
eJyLYGBgiFNX09VSTgjPV+Qo2Sd9bfVBKffzQGEGKc35GtO07qn36T7X7dZ7b+xmEODNYqgVx2J4rrzO
+OSiOuOjZ0HqMpVlm+PUFdu49FM7mIyWtIPEfGIzYzWC7zVb+DbNbfLsXzYxOmJtTubrXSC55opK6/2V
l3ysq9uKvtfsPQ4Su15QaDq5SM/YsH6N4fSOz2aTuswsj/UddXaYGOK3Z5JihNXk7+m2k5wLnCYEVHr0
RdQLdM9vyWhS6wTp7ekRrXWYOL2uavK95o3Ttkx+PcNnyesZatsNplcd3TL14KkzPSE37rRJ3imuu3Un
JUfwGkhP3NYuyehts1VnbTOzBPH11zuLiOy0FwSxdx1arP3n4HwN5/2KWiz7n+v+O7DFvPRIoanZkee6
IPn5ZyRVYs+u0Lt3ZkkkiK9w5pbKtfMRyseuRigfvnZLheFGrtHha++Ngy5qGTCMglEwyAEA1nSNaQ;

DEFINE COMMENT 1
eJwLYmBgaDBqcmwwWhHDbnBpBZDLkKKqZxyj8drAU1/LQM3mvbGkY53dJOcQv4vOjyKEnQuTZznszd5k
frIEpDbCsSn/jCtHyR7viHpj/9QOgwC9/o3+VdNN/Y7OP+KhtGWqk/WxO/YMp1ZYHzy1QE1r1za5JVtB
+npLJIMmFM8Pm5unl3gi7lKVS4Jkw6c0tU7Psr0zQfLtfaUWZ3o2JN1sv7RiVrvzGZBYS7+WQdVkFudt
UwR9NGZNrp4979rqwEX2J0FyHH1H53+bwjL/8kL3hSB+2I4+mUk71xhO2nnSDcTX2dAmJrjroNC/AweF
QPw3x/WMNx19bfDzkJ5x1aFKa4vDzk7fDre5FB11d1114qjz8pNNjs9O1tlpnPxsBlJ/7pKabv+lc+Ug
ds/l98btV/WM7W/ssKq/4ezkeq3LnWEUjIIhCgCnBIVa;

DEFINE COMMENT 2
eJxzYWBgMPXrcv/me9S53qvJscvtqHOwM4/nTYdbQcm2ZukZ1pOrX1lldq+w/jwpwW7ntCqfulm5gXtn
ArUxOFf0ewUXPYr4msqQl5LTVWpXdasBJB6+wMxy2oK9tjPnT/b9ME1t+4/JPpc+T83sXjOjLgckL7qw
zi5wUZ1d9xJnJ/ZlXe51K9Wiy9Zcqipcd3R+8ua9x6O3+VwCqVOdzTL//Tr72SD2wevXFPfdmCz/4e5k
ea0H05WWPdQySH9oZql7v83l621Bn8brEYG8l2cHc1+JCNx9c3pA/r3ZwSmPlkSC9O741OZS/ZHF2eVd
m4vb25Nubm9F/Q+9kw39/ukeEJ/1NPs8PeDL55iQtd9SoxhGwSgYYQAAJ3p8Og;

DEFINE COMMENT 3
eJyzY2Bg0LSutC42D/A+YFSX46P3Z4aI9vxNQGGGFda5RrMcKq0nOfN4nnEtTD7uzjCn3uvxFpBcgcXj
tmDn1A4Q2yolIfxA4vPoGxGlaVU+RwuN/U+WLAnhKV+RJVoLklea4+xUMpXBgbvX3XV6h6DPopZ7oS8b
3ye+aTiY96ZBsU2zyWfJ0ub5m6Z3/DnG3dt2rqW/7RxI35yzl+RELwjKnbxyTZH1mprusau5Rqcvl1pc
vlBnN/PcQYfp5+vsTl+2t6+8xeEGUi/y4rVB2PMVeg8eq+k+epSpn/Io1+jRo722cU/s7aWe7bUNfGlk
5vfK2ubUawYHhlEwCkYBGAAAtVdpPg;

DEFINE COMMENT 4
eJyzZ2Bg4HSfHRzsLBmUbHsvNM/yfaKhxZ8sQ4u2omwrxbYEu/f9513MpjJ6/ZiqHbRlMlA5w4Tia/6C
xTEhVwsVI55ml6aZp7oXl6V6l6nkBFSC5FNy+iuqqydXg9g/Jjs7ac20ngFiV002s9w2ZYv5mhlbzG/M
/27pv/iPzeHlR52ZVpx0a1sWESi6MDchfEFh8rQFpWnFa0NqNqy71fB+XUKr4brM7v8r/sy4usBnybJZ
IatMp05f4zDx2mqQmftuCMrtvnlW+sPds9KZDy7JqTySVV/2UMsg5/574223P5t9vb3DavGjk27yTyb7
PnicEJ7y6Hl0zv018ea318QzjIJRMAoYACOpcuY;

DEFINE COMMENT 5
eJyzYmBgqDb5Y7PLRCtur/HOaUAuQ5/uGsP7dloG8WFGZqdjd1gxJdbZMSUedb4QPdk3P0Aten3A67h5
YUcLZcNPliwMFay64lQ13dEoYu1Z3Yi1F3QurQCZMaE4NUqw+H3i1cLv6XF5bUVPs7tKxQtFa9803GsG
yd+d6+3xePZZz9czpgdsmfo8umbS3mzmCfeaj/Tr9TtM3Dtz52SORbozBFfEzItY+3+F5LpPayHmWt3i
kNh2u00s/SGHhMzTs9IznokqSj27pbLgsaJW5oPnuqvvvzaY98TaRubpUee4J13uLx70e227HeDNMApG
wSjACgCouGjl;

DEFINE COMMENT 6
eJzzZWBg0LSWDFpqc7Jkka3kOiCXgV83ItBT/5KPo1G/l6b1Wc+bDoI+TZ6yoXu8V8TUehuldLkx5E13
vFQFUsvs6V2200e01tj/cZtuoPUM3UD3hcb+k1eW+0asbXd/vCXDesUOR6PUbRN0ZDeC1C/I1YpTzN2Q
9CLrT9aOFJ7y07ER9fZJ81vOlmj1gOQXzxb0WTmz34thoqBPT8/s4IgOvcSHLe7Fas3zW9SaS6c8aXae
l9AasFysc/Z6r16lLVumzt8E0he9TVBOcNclOZb9s1X/HVis/efge2PrQ3ttGw7weB7fe83/yg7Z0Fnb
ZEMv7ZwdvP/AkkiQHo6r9oKs1wR9jl1dEQPit1zbYVV/Y4u5+e0t5kZ3v1vm32NxzrkvG/r23pJIo7sr
Yn7fzIxtv5oaxTAKRsEwAgCOt36/;

DEFINE COMMENT 7
eJwzY2BgmOqkFadiuyY+26ow+ZP5n6wdpt5lu0xkm6tN3vdbmu6dqWfZv+y6472NZ1znb3L1kN140HP2
ekav6WuAWhkUc5dEZmbZ5xamh9TYJK/o2p2s1/8ia+e00lqORSD5gxPOejpMTI06OOH5doaJr3fVT5y/
ad/EgOUguarJ9vYas7rcZ8+bHjBxUWbsiaVN+Uwr5rfsWP16F0j+30TFNvuVim0g9u2zPNJTLnRJ1tyc
LG9++5ri19sxan9vqOmKXii1mH6+0nr3zcm+v29OD+i8ohYddU4rjmEUjIJRQBQAAKgEX28;

DEFINE COMMENT 8
eJyzZGBgkHQU9PluyjAHyGQ46LnFfKePmWWR/x8b3UBnp6wgQR+N4OfRy4Nf98wLC1gOUpNn+T3dw906
a33AzgwQ/3pBRKB83pJI1gSecpaK+S0gsfIp3h4gur9b0OdOm2SQWvPzaL0Gs/RNdSyFm+oCKlc1Krbd
acvta+/7MRWkzrV/si/zhADvLVND/ED8lv7CiVaTf0w1mmY2NX/650m6M1Z0gcT1jjMIPT7FIHT7LIto
+PmTEtfO98nInr2mmHVCVj3rxCOt2LMbTI5dPejQfvWos8Alb4+sE5N9GUbBKBgFOAEAjctWiQ;

DEFINE COMMENT 9
eJxzYGBg2G0lYL3byrvsvcX2id/8rXuWhIT0zoyYPwEoxfDIr9okKODl5DY/2wsg/ul4CYOF+cnGkQVT
TF/kaS9iz3l9HSSemtzWr5a5feKfCog+5gkaUj5tJYm/Gj92WNbEHYuo7PgKElecVm3CuMjQ8NESQ0O7
pdUmj5bsc7oxf/rs2XNebY2bGXfs3fRL10DqJk6/MMl4JcSsvH3PdV33aMVV7po+u3KX8fTPB5a3/jmq
3SB1Rrvh+dmYpi3nubpOXLgw6c7FvA0qF6fv/X3u4CmpMwuuNJ4wvW1wpP7e5wPpdxfueX39wM5bp0Hm
Ce07p8N+6LnuystbtRlGwSgY4QAAqxx3jQ;

DEFINE LABEL 0
eJwTYGBguJ/72mB15iUfp0SjSSFRmc+BQgxxeffUg4tOlgQWW8/gLPt8wLnC/fz2GsFrLxsnXwfJ1yRP
Xnm94NpqhlEwCkbBkAYAAF4bTQ;

DEFINE LABEL 1
eJxTZmBg8IozMuuJfZ/olNh2DshlqPeytqnyKbWYGZGpvyMlRWdunpru3qodVpY1Bx221ob4faktTN5V
zZDnXOFd5lcSUgPS0xcT0+SUGFFvlRJRvzrzUtX1gv4Kx8prtaW1S9qXN+2dmdrctfh5k9KWNw1bDm6q
Yzi1t+rkBf6SS9cUc6ffakycfutlUP8VhlEwCkYB3QEAsvA+ew;

DEFINE LABEL 2
eJyTZGBg4OjTM37SrKbLUpGiE1b42mBxjrXN24zJvpvTGPI2p81u1M9omrsiS3JdXN6GfcfL+q80VF67
uanu3v2IjtQn57ofP9o5OeTGwjlVR4FGMfT0bDA507PFnK3fzLJ8ipnluumfzRhGwSgYBYMWAABvAS6U
;

