-- HUMAN RESOURCE MACHINE PROGRAM --

    BUMPUP   14
    BUMPUP   14
    ADD      14
    COPYTO   19
    JUMP     b
a:
    ADD      19
    ADD      14
    OUTBOX  
b:
    INBOX   
    SUB      4
c:
    JUMPN    a
    SUB      19
    JUMP     c


DEFINE LABEL 14
eJwTYWBgiCw46ylYvMPqbImRmVu5nnFt1Xtj47pSi1WN9vbKLd4eCq2SQYtatOKWN+3N3lQXUClYXDU9
Lq9/2a38SyvsqgKW76qevHJrbcyG3IbHWxhGwSgYBUMKAAC1dCLO;

DEFINE LABEL 19
eJwTYGBg2JFy1NkqZUmkfZJgFUNSaod9UumUmmTnedtSeZe+zZi8ckHupRXBRd5Laqt+TAUqZ/hTtTPD
rPbPjLUNDKcYRsEoGAVDGgAAU3Ybpw;
