-- HUMAN RESOURCE MACHINE PROGRAM --
-- 39-Re-Coordinator - SIZE 89/14 - SPEED 40/76 --

-- Based on 35.44-Otto42.asm

    BUMPUP   14
    INBOX   
a:
b:
c:
d:
    SUB      15
    JUMPN    q
    SUB      15
    JUMPN    k
    SUB      15
    JUMPN    e
    COMMENT  0
    OUTBOX  
    BUMPDN   15
    OUTBOX  
    BUMPUP   15
    INBOX   
    SUB      15
    JUMPN    r
    SUB      15
    JUMPN    l
    SUB      15
    JUMPN    f
    OUTBOX  
    BUMPDN   15
    OUTBOX  
    BUMPUP   15
    INBOX   
    JUMP     c
e:
f:
g:
h:
i:
j:
    COMMENT  1
    ADD      15
    OUTBOX  
    BUMPUP   14
    OUTBOX  
    BUMPDN   14
    INBOX   
    SUB      15
    JUMPN    s
    SUB      15
    JUMPN    m
    SUB      15
    JUMPN    g
    OUTBOX  
    BUMPDN   15
    OUTBOX  
    BUMPUP   15
    INBOX   
    SUB      15
    JUMPN    v
    SUB      15
    JUMPN    p
    SUB      15
    JUMPN    j
    OUTBOX  
    BUMPDN   15
    OUTBOX  
    BUMPUP   15
    INBOX   
    JUMP     b
k:
l:
m:
n:
o:
p:
    COMMENT  2
    ADD      15
    OUTBOX  
    COPYFROM 14
    OUTBOX  
    INBOX   
    SUB      15
    JUMPN    t
    SUB      15
    JUMPN    n
    SUB      15
    JUMPN    h
    OUTBOX  
    BUMPDN   15
    OUTBOX  
    BUMPUP   15
    INBOX   
    JUMP     d
q:
r:
s:
t:
u:
v:
    COMMENT  3
    ADD      15
    OUTBOX  
    BUMPDN   14
    OUTBOX  
    BUMPUP   14
    INBOX   
    SUB      15
    JUMPN    u
    SUB      15
    JUMPN    o
    SUB      15
    JUMPN    i
    OUTBOX  
    BUMPDN   15
    OUTBOX  
    BUMPUP   15
    INBOX   
    JUMP     a


DEFINE COMMENT 0
eJwTZGBg2FZ83vFeuaetVF2iTVHzPOd3LXe8rFoZgxe1zA+bVv8yrazCuFyszLh8WaVxeVDNpSqnpq4J
cY0/pt4rT1tXlbtkK8MoGAWjYMgCABLiHv8;

DEFINE COMMENT 1
eJzjZ2BguJX/3OFZiaetUKOBXVHzPGer1jtedR1H4sQ6j7UYdbzu4WpZP+Na1YOVz0oerPxVtn51VI/f
+kXT/dYzjIJRMAqGPAAA6tAd0g;

DEFINE COMMENT 2
eJzjZWBguFSkFn2oYkforabtTvuabd2tWguy21pl5oW1OO10agq4ClTCkFVsfq2riv3Grr6TFxhGwSgY
BcMGAAACbBX/;

DEFINE COMMENT 3
eJwTZWBgmFb/xXNZ5YvgdWVfY/xKLqYvKmSq3FeQ2sFVKDMvq7h+rVgZ66agmj1b2lr3bDHquLL5XpfZ
hl19lxfM6/8xla0/taOsOzzHr/1rjFNTe/i1KsZghlEwCkbBkAEA/98oyg;

DEFINE LABEL 14
eJzjZGBgCMxd6NNQnOAgVuttOKF+qk5twwWNXY331Jc3TdWJaHK8xjAKRsEoGLYAAPboDjc;

DEFINE LABEL 15
eJyTYmBgyMuYrVqYnqBpkrbBpCUhxE8oekvqg1Ce8tSQ2Y3rA3L7PvtZz/jsd3DO+oCj85eEHJ1vkvZj
qnNF4USgVoavqY+0tqU+1y1M5/HckO5evDpTsW1F1s5pWlkhq1Zk9V9ZnSl7/1Vm5nOGUTAKRsGgBAAX
ji7h;



