-- HUMAN RESOURCE MACHINE PROGRAM --
-- 29-Storage-Floor - SIZE 5/5 - SPEED 25/25 --

a:
    INBOX   
    COPYTO   10
    COPYFROM [10]
    OUTBOX  
    JUMP     a


DEFINE LABEL 10
eJxzYWBgENKxz52nvjMjRfVPlpaydZa+Yl3OZvm2ohJ5waoPCmt6tZTtZ6eoei8J0e5fdkrv5KKjBk1z
Dxlaz2AyKpzIpd+U36F/smSvcULrBoud01RsTy6aax+w3Nvt0gqg0QxrAhdrvwyqtF4YGuAdFfE5ZWaE
0SSpiD8zYsIPzkkNOTrf2N9+9h5vs6n7vQonNnnOb2nynF5n6sdS+DikLgek/2j5Iy32cj1jt/I/No6V
qVGOld5lu6q3TK6uPjp/b5X3kuaKSyv8Si6tiCxwnnc3r3Di7PwVXVcLZZsbKqfXmdUGVILM4OiryjzT
s3cmd6/3kva+2euP9VVNP9kb09Q0QbBq5UyWwrOLnQtA6vLWByxnGAWjYIQBANVtc+g;

