-- HUMAN RESOURCE MACHINE PROGRAM --
-- 34-Vowel-Incinerator - SIZE 19/13 - SPEED 157/323 --

    COMMENT  0
a:
b:
c:
d:
e:
f:
    INBOX   
    COPYTO   9
    SUB      0
    JUMPZ    f
    COPYFROM 9
    SUB      1
    JUMPZ    e
    COPYFROM 9
    SUB      2
    JUMPZ    d
    COPYFROM 9
    SUB      3
    JUMPZ    c
    COPYFROM 9
    SUB      4
    JUMPZ    b
    COPYFROM 9
    OUTBOX  
    JUMP     a


DEFINE COMMENT 0
eJzTYGBgYJaar8Es9d2SVVLUv0esKR8oxFBsflLCzthbys1AUsVHb41ht95eWxZDd9f3FifdnlubWarY
pugk206WV7P5Y/Pc2igFpGfG9j6ZW9teG9zaVpgM4gdd7JLMOtElueb4Wek3xzeY8F42s/S6UmntftXZ
yf2qt0f/JdnQx6feJ4LUqj/skux40yTc9vaoaNvbLsnAl891V9//ns4wCkbBKKApAABQVDzN;

