-- HUMAN RESOURCE MACHINE PROGRAM --
-- 10-Octoplier-Suite - SIZE 34/9 - SPEED 32/36 --

-- Based on 33.33.unroll-sutch.asm.

    INBOX   
a:
    COPYTO   0
    ADD      0
    COPYTO   0
    ADD      0
    COPYTO   0
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    ADD      0
    COPYTO   0
    ADD      0
    COPYTO   0
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    ADD      0
    COPYTO   0
    ADD      0
    COPYTO   0
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    ADD      0
    COPYTO   0
    ADD      0
    COPYTO   0
    ADD      0
    OUTBOX  
    INBOX   
    JUMP     a


