-- HUMAN RESOURCE MACHINE PROGRAM --
-- 32-Inventory-Report - SIZE 26/16 - SPEED 341/393 --

    JUMP     b
a:
    COPYFROM 15
    OUTBOX  
    COPYFROM 17
    OUTBOX  
b:
    COPYFROM 14
    COPYTO   15
    COPYTO   17
    COPYTO   19
    INBOX   
    COPYTO   16
    INBOX   
    COPYTO   18
c:
    COPYFROM [19]
    JUMPZ    a
    SUB      16
    JUMPZ    d
    JUMP     e
d:
    BUMPUP   15
e:
    COPYFROM [19]
    SUB      18
    JUMPZ    f
    JUMP     g
f:
    BUMPUP   17
g:
    BUMPUP   19
    JUMP     c


DEFINE LABEL 14
eJxzZmBg+CxkmB+qeiSlzup53Bsr2RQzy9+ZbXovOq8pT1n2V955i4Bc+P6FCksPeJkf3+XgprgLqIVB
IPJLO1uGa9XdvDOF7/MN89UK1mZMzZ0Z+zCDK7IzmSvySKxDnGnE78wdwdX16oE9M9UDrZdbBqWtyw09
vut69KeDKSkXjq/MvnC8IK/pWFP+88MgMzdWr824UtvftbrF4XBJy58pD9pDMuM7LySJdvfFL5nwL6py
lmg4SN26nf+itmy4kJS/sivv7NLqevElLT0PF3NMfriYdVHrktpVLMvmbP6wvHW7x9rkvVmbNuy7upVz
n+PO47se77m/jeXQ6dVTj/TMZD56t1vs8JuqVfun5XTuupB0devzOIZRMApGIAAAdXmFYQ;

DEFINE LABEL 15
eJzzZ2BgeKs4WzVIZLbqQz4jMzXegw4vuWVD1Xjdi+/xP26bImw2tV+0btZpMfvZlbL2s8vlPk8CamFo
dzcyk3R8b1xm5uz0x1gy6ICRWfoBo5Mlv0wetz2xYZkf4HJpBbPn5JW13u4LLXyrpm/3zey28K3LqfL5
nOLsOTu438XddbqjmeVc+89mIPOkIt4bS0UkhItGORcci2eYsy/Je8mPFJb5H9Kn173K3GEFUtNcYW3z
vYajpLQ2tw/E31W9xvB7zXtjvQYGh4wmQZ+HLc+jp3SqdXL3Msxx7V/Svm/iBhOQuqPL9IwPrJjs+3dl
U/6vVf3LQGIP5ihqXV6oqGWy9pbK0k23VEBi185P9g290OfFeu2oc+N1Bgfz22sMS+5k6m+8O1/j6+0m
x6+3r/mvvl83a/X9Syve3pPdyDAKRsEwAAB8tISV;

DEFINE LABEL 16
eJxLYGBgqGCbrbqdTdDHgdl7iTXruaVzBJrmMkuxzLeVcV8IlGaYppWiI6Oxc1qceumUBWqZ3Ylqkg2J
amviZTTWGIprPdI6oS8o98uER1rHarI8SD2L4YakXSa5CdEOeokgfoj2ml5+3ff9QH4/iK8QJqmSFHpy
EYhd7zVbNSQqQdM+KUFzW+pibZDYrmo13eI6e/tNdRxum+qMJr2vT9z8vn7nEZDc3bxHWrkNj7Tuta7Q
E+7K1Ofoe64LEo+Z995Yfm5V5u15B+fcnuddtmxWik7k/DWG7MuMzH6tKrUoXrvFHKTu9BL3Ytbl7sXZ
GwIqQXzxBQHL/6/wXpK8WXAFiH98r7MTy37Z0IYDCa0NB2Q3/juwYse/A7xLD+0/V35o/5LIn4e+Wxof
/W758gSDQ9LpAG+FM7KhD0+rRWecfB1nfehzyq5DVZlrjgtWqZ1633/z3K11IDPZ394LffOtzeX5D2en
hN8szsm/7oUm/7Ke8fyHJFh+FIyCgQQA2DOaLA;

DEFINE LABEL 17
eJyLYWBgkNGwtlFX+WPDLHXUOUowxC+Jb35YKm9ughpvSM1Dvr0zpQUj1gqLrNixWf7zgTj1skM3NLcc
vKqVu+eqltIWoHaGfhfFCDn72Y0Jdmt659sB1TucWyrsnLjZ2+39XmZP88M7ff4c0w3cezw+bMtBoejU
bSfiTi5qSdDqaUngKe+M+5wyMXpJpFSEZNBvbx7PM67eHhed+7yuO8aEgMyeWnjSTaQoxC+4qGnu2RK1
7a3lZYf+V1ofy234c2xRy4Z90u2Jm0M7ORYJd73uudLJU36t430iSN+3KbKhn6d+TzeaNn3Nxmlau0Bi
NZMu+byeUZcjtGj+prZlRgccV+TusV85e33dyqPz/6/4k9W8fH4Y63J7e5BakZ1d7s773RdaHIboldtq
Zim5vdKab3el9bOTG0xAYlLPIgJvPAvxE3o5PcDzzZLIo29zE/6/dy7Y+2FF194PpVMa3h+dP+Hl9DWR
z2I28LxesvXV9w37GEbBKBhkAAAre6ZE;

DEFINE LABEL 18
eJwrYGBgsGC7pmjBJupvzZqbYMfyvp+RuWsxI/OWg7cFyg7NFDQ6AFTCUCJvZJavaDZ1m1z/sh+yDHPM
5a7VmsqviNFXPOigqyQo91ZxtqqP3mzVQ4b31P8bPdIC6UlRTY2yM14SWWamFg3iFypMX9NseGvdI1vJ
dSD+y6D5GkmhSyKVQxNaNYJvgcVOunlLHXc/K/0g1FvqdOxkeZDY95p76hU19rm1VXr9+yvf7wWJrc48
KeFW3iX5vcZdfFELjzRIbNms2aovZt4K0p0RUf9uuuhqkNjj2SEK5mtmq4LYN+brJTYv/54OYq+c+Xz7
7XnzN3UuvbXu+UaI3Sz7F2uz7Bf0YTxwrpzxAESs4QAwbA5fU3xzPEZt4ennulHnjMwuXzjqLHwxwDv0
QkzI7bOpUUVHd2Z8POpc8PKEbPPjU/3L4s/M3wTSK/LioEPgy0rrjjefzQ68L7Ww/GRtY/KFxdnwq6BP
3rcVMXnf/mRZfqqbVffBfaHLO8EVE15eWz35heQ6+Se31ik9Fl29+FHX4sTHbQvCnjPM4XltP5vp/dH5
vz5eWqHz/d7G+7+XbJX8t2QrwygYBRQCADr9wI4;

DEFINE LABEL 19
eJzTZ2BgKDO7F8pukBC+QO194mqlvdnb5CZXM0i/7mGVtJ99TCJkVaPU8+1WskYHMpWtj4loVx29oPP5
AFAbQ4DLhqReV96l7e5GB5w9D56y8J18vdTv2k2DgGs3s4IuXUsKZTkbFZG5c2K00SSvOLVokJ719VWZ
ljX37lvWfD7wvt4+N7sxM1ateX7YopZ7obFtCeGhnbkJR/r7K/ZMUuusmVQ4kWHij6kB3W0LArr7l3n1
3ttYNC3g6rJZSo9uz8t9xTAKRsEooBgAAHmAVOY;

