-- HUMAN RESOURCE MACHINE PROGRAM --
-- 35-Duplicate-Removal - SIZE 42/17 - SPEED 63/167 --

    INBOX   
    COPYTO   0
    OUTBOX  
    COMMENT  0
a:
    INBOX   
    COPYTO   10
    SUB      0
    JUMPZ    a
    COPYTO   1
    COPYFROM 10
    OUTBOX  
    COMMENT  1
b:
c:
    INBOX   
    COPYTO   10
    SUB      0
    JUMPZ    c
    SUB      1
    JUMPZ    b
    COPYTO   2
    COPYFROM 10
    OUTBOX  
    COMMENT  2
d:
e:
f:
    INBOX   
    COPYTO   10
    SUB      0
    JUMPZ    f
    SUB      1
    JUMPZ    e
    SUB      2
    JUMPZ    d
    COPYTO   3
    COPYFROM 10
    OUTBOX  
    COMMENT  3
g:
h:
i:
j:
    INBOX   
    COPYTO   10
    SUB      0
    JUMPZ    j
    SUB      1
    JUMPZ    i
    SUB      2
    JUMPZ    h
    SUB      3
    JUMPZ    g
    COPYFROM 10
    OUTBOX  


DEFINE COMMENT 0
eJxjYWBg2Fui5tJanlr4pmrRfoZRMApGwYgCAL/hBjk;

DEFINE COMMENT 1
eJzjZ2BgCMy9EllcIRu6tVY29FrH0aiA7pr49L6mfLZ++5b0voYJPT0XZqt16i170jx7fWv55AMsdRFH
Ts/zPMowCkbBKBjyAAAfsBuN;

DEFINE COMMENT 2
eJwTZmBgeJ+7wdu256ynwcTJvisnRwSaTuUPa5l6NKplak38j8miaT09WqUWHQ8q0/tOdi/pfztzSf+m
ue+6mVZObb6z+0zD/r1+VYv2fyn8tZNhFIyCUTDkAACqnCdh;

DEFINE COMMENT 3
eJzjYWBgeJVpHXwja1ntjaxNcx8VVSyUbmxb8Ltt01zG7k1zgdIM3u0rYrzbt5972c52i2EUjIJRMKwA
AChjFjs;

DEFINE LABEL 10
eJzjZWBgiMuYnxuY+7XjUdGSecUV+Zv0GnSOA4UZguvW5fhVKbatKr0w+32u2vbCdP6TdUm5lxlGwSgY
BcMGAAAk1xZL;

