-- HUMAN RESOURCE MACHINE PROGRAM --
-- 02-Busy-Mail-Room - SIZE 25/3 - SPEED 20/25 --

-- Cheap tweak of @peterfreese's solution: adding a JUMP makes it non-input specific

a:
    INBOX
    OUTBOX
    INBOX
    OUTBOX
    INBOX
    OUTBOX
    INBOX
    OUTBOX
    INBOX
    OUTBOX
    INBOX
    OUTBOX
    INBOX
    OUTBOX
    INBOX
    OUTBOX
    INBOX
    OUTBOX
    INBOX
    OUTBOX
    INBOX
    OUTBOX
    INBOX
    OUTBOX
    JUMP      a
