-- HUMAN RESOURCE MACHINE PROGRAM --
-- 20-Multiplication-Workshop - SIZE 25/15 - SPEED 106/109 -

    JUMP     d
a:
    COPYTO   2
    INBOX   
b:
    COPYFROM 2
c:
    OUTBOX  
d:
    INBOX   
    JUMPZ    a
    COPYTO   0
    INBOX   
    JUMPZ    c
    COPYTO   1
    SUB      0
    JUMPN    e
    COPYTO   1
    ADD      0
    COPYTO   0
    SUB      1
    COPYTO   1
e:
    COPYFROM 0
f:
    COPYTO   2
    BUMPDN   1
    JUMPZ    b
    COPYFROM 2
    ADD      0
    JUMP     f


DEFINE LABEL 0
eJzTYWBgYLa757rNpiz/t5VOb5a1/jo3z0erbgeYrAFKMRxIbO7pyVzY8DuTrUo2U76gJW1m4vdE8UC5
GIs0h2jNHIfoz40sCVOXf0/sXm2e+maZVrrdCpC+yZVh85iq8qfwV2jmXC/PC6isPaSn3mijENWWZgiS
l6+zSCvu70/tmGCbAuLrzivVZp7zx1JgVvQcibl2K17Of7Rqxco3y0By3+ZGVH9ZFVEdusurkWEUjIJR
QFUAAFOjRSA;

DEFINE LABEL 1
eJzzYWBgeGXS4zLVIGvaVIOMnUAuw0TTJo9Njqd8jzvJ+Js5ZwaJuKyJ/OhSWOjtElzb7zS95aHdnKY4
A6miNOOk8sNWht1nbFNnLHXevwOk90/Mu2axSLsVFhHS20B8uZgmDxDdVh1ca1hu3X6niG+mc0H3au6C
3O0yZU9PW1ZVXXGsVb66uN7o/MHmXbtcW2ct3dJ6q5u3NaL6YPOqmh/N75pPtkXPqeiafOpI9+b7R7rv
fUjqvPJlTVP7x13FifdO57A+XJiVdgdkx/nFayLZlmyp2LVo7VzThTUb/y2I3G+6UHqb96LG9QuWBS7Y
uyprWthaztnzNu/f4bolbq/UpvfHWTeuPgDSK7l/RXTH/v/zrh5I3v3/0KuTM47WXyo7VnUl88SDsyB5
zaOcs1eeLpnEMApGwTADAF+4kI0;

DEFINE LABEL 2
eJwTZWBgMCyPD3OrMOt8Ujpr6ZPSygkLyq9nnaoUD9SpMXX90HAgcE3Tr5iDzQ/TGNoTZs2uSZhVWLVn
ulvFhX7+it6ONxWT2piqejsqayWmqjdOXd7Z3LaWYRSMglEwZAAAxtsn+w;

