-- HUMAN RESOURCE MACHINE PROGRAM --
-- 37-Scavenger-Chain - SIZE 38/8 - SPEED 56/63 --

-- Based on 44.56.unroll-mrflip.asm

a:
b:
c:
d:
e:
f:
    INBOX   
g:
    COPYTO   22
    COPYFROM [22]
    OUTBOX  
    BUMPUP   22
    COPYFROM [22]
    JUMPN    a
    COPYTO   22
    COPYFROM [22]
    OUTBOX  
    BUMPUP   22
    COPYFROM [22]
    JUMPN    f
    COPYTO   22
    COPYFROM [22]
    OUTBOX  
    BUMPUP   22
    COPYFROM [22]
    JUMPN    e
    COPYTO   22
    COPYFROM [22]
    OUTBOX  
    BUMPUP   22
    COPYFROM [22]
    JUMPN    d
    COPYTO   22
    COPYFROM [22]
    OUTBOX  
    BUMPUP   22
    COPYFROM [22]
    JUMPN    c
    COPYTO   22
    COPYFROM [22]
    OUTBOX  
    BUMPUP   22
    COPYFROM [22]
    JUMPN    b
    JUMP     g


DEFINE LABEL 22
eJxjZ2BgSK002VZQVTh9Um1F8qTaN5FAIQbdGiZ1hlEwCkbBsAcA+Z8I0g;

