-- HUMAN RESOURCE MACHINE PROGRAM --
-- 36-Alphabetizer - SIZE 31/39 - SPEED 74/109 --

    COMMENT  4
a:
b:
c:
    COMMENT  2
    INBOX   
    COPYTO   [23]
    JUMPZ    e
    BUMPUP   23
    COPYTO   22
    JUMP     c
    COMMENT  0
d:
    COPYFROM [23]
    OUTBOX  
    BUMPDN   22
    JUMPZ    h
    BUMPUP   23
e:
    COPYTO   23
    INBOX   
    JUMPZ    i
    COPYTO   24
    SUB      [23]
    JUMPZ    d
    JUMPN    k
    COMMENT  1
f:
    COPYFROM [23]
    JUMPZ    g
    OUTBOX  
    BUMPUP   23
    JUMP     f
    COMMENT  5
g:
h:
i:
j:
    INBOX   
    JUMPZ    a
    JUMP     j
    COMMENT  3
k:
    COPYFROM 24
l:
    OUTBOX  
    INBOX   
    JUMPZ    b
    JUMP     l


DEFINE COMMENT 0
eJxjZWBg6FMM6n/TyT4h8bjFTJl34bMZRsEoGAUjBgAAIuoHlw;

DEFINE COMMENT 1
eJyzZWBgYNL38LupK1AfoPe1473+hMnfTV2n+Fh3t4vayVZV2scl2tmf7NZ2KJwY4fJryjpPke4j3jta
xPymlG31N0pJD0hyARrBcDR659o5UaEPQezyGP1GEB3QzeX1ou1RRGbD7vSZ5aUlUSU2NTPL/Zr1Jzxd
BZL3XDo9cvoS1Uy+pfqNCcvn9s1fxT7hy3rFtstbppQVb9udLrSjvTpl18nu3t1z+wwOFE7cd2hu36tj
R+v9TvwrZzz5KAJkxr5Ln5YKXGVZK3Jjwz7Gm/Jnjt0wvJx0/czdmVeKH387r/Fk0rl9j1JP5V8vP8l7
FKQ+7opsFcMoGAWjAA4A5UFunw;

DEFINE COMMENT 2
eJxLYWBgyFRmMOJUTc49qzJ1/iclaQ1plRCFFWqJ0le1nCTf66+RkjEJUfhuekFjpVmn6UqzRrcGU/4w
PeMv8e/1CzLMNM/m3dTNqJQwjK777bFo1n/vqfOBRjIsD95c8SP0UpVQ9JSyqvim/J+pKxNM0h5FuKd+
CDZI/usnFB3qaRK232urf0FGj19pSY/f0XrJwBe9y4PXT02I+r9AN2H5srqk5cseJ39aGpkit/hnqtcC
kLnva+akHqs+kfS87ESSe6lRinxJf9aSgq8dugWS06ULBVfsKpq1WqDCf41IdceS1FqeOTX17BPCG98U
uDRJTs9tPjinufU/2JyWqXeVX0ybbaMy/Wf24RkH5+yZNLevpv9Fb1ov+4TDHW9nCnZoz/PpuLx4Q6fB
qrTeNZvOTQzeET9dfffGmfVbA2YLruiZDXFP61aB+nXbeOaU7xRcEbT76Srn/cdW7DvUPKPgcG5r4vEH
84JO2y7NPPtp6dlztktzLkydz3Npbt++S6UlIL2MN9c637mVb7/7foSO8hMW0cNP63oYRsEooDMAAH8L
uVg;

DEFINE COMMENT 3
eJxzZGBgmGf72v2NzbboebbMLXb2apPuOjTPqHVaNIvL1WKmp0dQv5jf2bwqf8boxQHd7TuD9kx4FKw2
iTs0qN8rwq/ZLzqs6HbskTCxuEY3oFEM+1IvL25KZb0GYq9O29ECop+XHbfsqubyymxYGtLeIZxUNI27
+FTd+qlzq/4vmFn+fSNIDfv61+731vpE3Vt7K7Nu/cea7A0C9T82tVd7bQ0r8tshnBS0O8klZdc9H81d
NjW3d33tuL/XuHfXfpFu76MZlamnvsRXn9H02X7mhxPYDZc6lry+lrdu8023vXduyZ8Jvi1+d+GtCy+P
3ah4f/XKow+Jxyc9VTvO9QikdsWF9mqGUTAKRjAAAMKfepk;

DEFINE COMMENT 4
eJwzZmBg+G5qqdXpLWRZ5jPb5og3l1eRZ3rAHtcPwdesjoRNcNwWfcCDLV3F62e2itfCwlVuVQ2Sjg4d
T8wcOgS0BeqB2hlM0oQsL6Ssdd6VFFZUl/R/AUispl9HX76FLV2izqGjpPLTUqXy1P0g8R+LGIyuLb9i
orP2iknnDiFL+z2zbVS3//U7skJ7HkjeaX5ybuRGiTwQ+8ZxVrv1xzR93A+5ZHMfmlK2+vDR+lfHmFvq
z/s1fzu/uSLq4tm89qusdu1XCzJ+XZp2gmEUjIJRQDIAAHJ4U4M;

DEFINE COMMENT 5
eJwrZmBg+Mudbz+D63lKLNfcvitc4bP/cnst8OP7v0BNVnI6UJqhmKcp/75wYNpzSaMUEF+Yz9mpQHKX
3Q3ZGisQf79GVYOPtpBlmsHSED1j3YhwE/4wM8t8+yLL45ZFljY1IDWeHi96n7p1xa1yYzBa57nV6KO/
oXV6wA+nKv9QzyPe1sHGbktDQOoyEj6b7UpaWLgryaEDxDePfGZdnGlnBmJnFmQZLyn44TSxcL/XriIP
P/mSv37Npfd8NtesMOdsOqS7vX6tc33R2bz7BbJVIPUBs+VNbs36Vw5iL1sgW9W69IxrwvIV5tkbZKu4
Nz1pNN/21091u4pDwvaH+iA1Bge62w0OrMuZenCBh9KRLGOLY+V6fid4dYNOTzOYdO6mg+GFyb4rLjyK
qD5jH3/0RFzi2XO3MqMuylY9vlDV4HJ+RwvLme72xONfO3KA5oDMM3qwwEPvbqin1i0Pv/ar26JNLwem
NV/iLv516Unj1Stz++ZeXz/1/c3mGax3mmdI35sw+ckDh464J7cyrz65Gnv1yZGwF4/TA5ofTfYFmRX+
LtRz+kf+sGtf2NL1/2Yuivj3aSlIXPuV65T/X5+nuP2HxMUoGAWkAgBSDcVE;

DEFINE LABEL 22
eJzzZ2BguGX7w0nd9p7PRhupA0Auw3/vlGk9fhYzp4RITi+OvD0pJbau536CfqNUYkblx/jSkvKYsKLL
4WFFO4Nsat76rJ9a5rNlYbLvjfX3AqQOfAniPVocyXBKLI7h1Mf4aSfqkiwPgcxckOvXHJS3Yd+SgvVT
p5bsaFEqn9lUUsncIlLd3c5YM7cvtfby4oW1E/eA1M6aPkkleso7rZC+mw5r2hYWfmsy7g1vnDo/vHHD
vm9NV87wtvbdjGvf92heV9oLkPrSmSe7rWZ+35g8S+qA3ZyHx0PmyZ/5Ml/+jOxChlNFy0S3dK74tHTj
yl9TxFb/3su8JnU/+/q9O7k3PV31atvJbpB+7kNfO34eOjfd5PCGfSD+1IPZMSB6ydmtRn+vdsVJ3D5a
z3l/y8InD6QOyD8UurjygcqNU7cnPWUYBaNgGAAAJB6ZMw;

DEFINE LABEL 23
eJxjZWBguB0rkbcg9tBRIJPBIPm4JcMoGAWjYMQAAEfaBds;

DEFINE LABEL 24
eJzTYGBgSPY1tP7tsfgwkMlQarMywdc7MC0hamEhiO+c9LFGKjFvXWz60Xq/bJfsvryuON0Cxuj6IqMU
nlLZqrlVL7dtrik/ptcgOb2h6Uljc2ty7ou2n9lvOn/vBen/P0O/UWPWu0NWM6d//D+jeqXGrKP1kvOs
g53m//WbvHCyr+fSTf7WK/nDTqyOS9RZ+zP745r7pdeWK7ZtnKk9z2za1PkMo2AUjAKaAgBNeEg/;

