-- HUMAN RESOURCE MACHINE PROGRAM --
-- 17-Exclusive-Lounge - SIZE 29/12 - SPEED 24/28 --

    INBOX   
    JUMPN    i
a:
b:
c:
    INBOX   
    JUMPN    k
d:
    COPYFROM 4
    OUTBOX  
    INBOX   
    JUMPN    g
    JUMP     b
    INBOX   
    JUMPN    j
    COPYFROM 4
    OUTBOX  
    INBOX   
    JUMPN    e
    JUMP     a
e:
f:
g:
h:
i:
    INBOX   
    JUMPN    d
j:
k:
l:
    COPYFROM 5
    OUTBOX  
    INBOX   
    JUMPN    h
    INBOX   
    JUMPN    l
    COPYFROM 4
    OUTBOX  
    INBOX   
    JUMPN    f
    JUMP     c

