-- HUMAN RESOURCE MACHINE PROGRAM --
-- 08-Tripler-Room - SIZE 20/6 - SPEED 20/24 --

-- This solution is level-specific (quantity-limited input).

    INBOX   
    COPYTO   0
    ADD      0
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    ADD      0
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    ADD      0
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    ADD      0
    ADD      0
    OUTBOX  

