-- HUMAN RESOURCE MACHINE PROGRAM --
-- 39-Re-Coordinator - SIZE 142/14 - SPEED 40/76 --

-- This solution is level-specific (patterned and quantity-limited input).
-- Based on 35.44-Otto42.asm

    BUMPUP   14
    INBOX   
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
    JUMPN    e
    OUTBOX  
    COPYFROM 15
    SUB      14
    OUTBOX  
    INBOX   
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
    JUMPN    e
    OUTBOX  
    COPYFROM 15
    SUB      14
    OUTBOX  
    INBOX   
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
    JUMPN    e
    OUTBOX  
    COPYFROM 15
    SUB      14
    OUTBOX  
    INBOX
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
e:
    ADD      15
    OUTBOX  
    COPYFROM 14
    ADD      14
    OUTBOX  
    INBOX   
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
    JUMPN    e
    OUTBOX  
    COPYFROM 15
    SUB      14
    OUTBOX  
    INBOX   
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
    JUMPN    e
    OUTBOX  
    COPYFROM 15
    SUB      14
    OUTBOX  
    INBOX  
    SUB      15
    JUMPN    g
    SUB      15
f:
    ADD      15
    OUTBOX  
    COPYFROM 14
    OUTBOX  
    INBOX   
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
    JUMPN    e
    OUTBOX  
    COPYFROM 15
    SUB      14
    OUTBOX  
    INBOX  
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
    JUMPN    e
    OUTBOX  
    COPYFROM 15
    SUB      14
    OUTBOX  
    INBOX 
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
    JUMPN    e
g:
    ADD      15
    OUTBOX  
    COPYFROM 14
    SUB      14
    OUTBOX  
    INBOX   
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
    JUMPN    e
    OUTBOX  
    COPYFROM 15
    SUB      14
    OUTBOX  
    INBOX   
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
    JUMPN    e
    OUTBOX  
    COPYFROM 15
    SUB      14
    OUTBOX  
    INBOX  
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
    JUMPN    e
    OUTBOX  
    COPYFROM 15
    SUB      14
    OUTBOX  


DEFINE LABEL 14
eJxjZ2BguFp40CG4yNpmf+Vs1dqq1wZAvOtP1fu9DESCi11r4u+1drkvanF3Lahncbau/mNDrN5RMApG
wcACAL1iFsM;

DEFINE LABEL 15
eJyTYmBgyMuYrVqYnqBpkrbBpCUhxE8oekvqg1Ce8tSQ2Y3rA3L7PvtZz/jsd3DO+oCj85eEHJ1vkvZj
qnNF4USgVoavqY+0tqU+1y1M5/HckO5evDpTsW1F1s5pWlkhq1Zk9V9ZnSl7/1Vm5nOGUTAKRsGgBAAX
ji7h;

