-- HUMAN RESOURCE MACHINE PROGRAM --

    JUMP     b
a:
    COMMENT  1
    COPYFROM 0
    OUTBOX  
b:
    COMMENT  2
    INBOX   
    COPYTO   0
c:
d:
    COMMENT  0
    INBOX   
    JUMPZ    a
    SUB      0
    JUMPN    e
    JUMP     d
e:
    COMMENT  3
    ADD      0
    COPYTO   0
    JUMP     c


DEFINE COMMENT 0
eJzzZ2Bg4NHqde/VDIybqPp64kTVOYuAQgz86tO8ejWL7Lq1iuza9aZ5NRmbhjKYekTXmyanNBtNKGbX
l6vo1ppQzKE3s6zVQL261jy296td15z3LjtWg/Q/9e11T/E7E/PE72r8Y3+t5SCxpABl/3vBve5XYqod
L8ZXO4LEHvuLlt4JnVkGYbtuuBuyfsX5xGVLQXyL8gzr3cXzffcW2UfsL5hQbF9wvuNg3t/pB/OMV4Hk
zSsyrE0r39qYVAl6rquXWKjb6LoBJL6/wLt9b9HeJvMKgzrDWoM6kNj8Xg43hV6m/Pm9PEXze1fXzOtz
apnbD1Ev1//fSWpShrXk5AzrmZOL7IRmSfnwzA+Ma1+8qLJh1cF1DavubG9cmbmndSnDEe4FDEcmzire
P3Ny5h6GUTAKhgEAAIBwek4;

DEFINE COMMENT 1
eJzzZWBgqDflcGM0EfTs0P2Z3akjWtqp493ObLRjNaOJ64YaC9cNFTY7VpfaKy756PR64gfn8x35LveS
ih1WBJTZTfP6adXiAjSCIcVP0DPZX8on2d80ND54b9PtsNcTw6PyJ3unHms9kN9eYFdYmrWvMDllXyGH
2/6CIju7wmrHfYX2EfsKV9fsLbJZCzJjXt9tM7n+XvfZEz9kSE1Sr5aapLV89kTjVSA5jdZLxhqtB3SX
t2mqzZnQICE2rVy0Y9EfMZDcu10HdLP3Qsx4dlBc4eExVqk7p2Yrhp930Q+9GG8RdGVXWPDle0k3zv3M
vneiveDpofYCkFqOxf+dOhfO9+VauLqmY5FTS/tipxb2JZaNzMu31DeuXFT5Z+3V+Jq1KwKq19lH/F6X
nFK1nm125QbFJQyjYBQMIwAAyluDig;

DEFINE COMMENT 2
eJxTY2Bg+GfGJ/vP7JJxvek0LwbTMzHNRlvqm420lgOlGLI8fY3euT5Pfe/ybi+I/8LrgG5ciH2ET8qy
pd6py5Z6pn+Z4p7JlH8w76TB/oJUfpAarRZrndVNu8JWN22pX9M4eb5Ok/EqkHjz8gzrlmXzfVuW5aS3
Lr3Z3bo0YSdIXHT6dq3eeevU/6zVVPu1fqnK+52aagyjYBSMAroAAI+hPWo;

DEFINE COMMENT 3
eJyLZ2BgkJE+HDlPclHlPMnGmbJSk+fPk2Q4AhRmkJPUCQLJCamc7+jUMV7Vpv/9AKvB012sBiFdLIY/
s1kM5/uC1H2zXRHwzXbOojK7ZUvL7BJ2frXL3PPVbtMVkFypvZTPG7eNwfeD7CNA/E+OryfmuVZMg7A9
7yT7H7kVH7z7+p3Q3ddBYoEJpqEBiYcjAxKvxp9JCek6mnVn++EchiOOeZzHHfIZjliUv55oUiVXYVz9
PFWvwUgTpGdf4Tf7jbUGdYu6Fpxb2M15fEGP64aZkz2ip019Yik2rVxUdLojM0jd73VSPtXrREur1q+u
qVr/d/rvdWyzf6+zWVu1/tRGkHzVekHPss2Bcfk7f2bn7bqX9GrvrrCsfYKemfuneWUcMA19fiAn/dnB
HatBaq9dOBx5/XxOevj51xOvnz+1MfRizSGQuMtDj2inx9ceHHx8/zGIf+BJaZbFm9heva/fD6z55rph
zbfSrNXfv9lr/3hrwzAKRsEgAADMYKmO;

DEFINE LABEL 0
eJzTYGBgqLD5Zv/TqsXlv+miyhbDO9tbDXQvA4UZyuyeWH61k/L56PQhI8/VqeW1+8yyhCBrnRuRjszX
o1L5Q2M43K7EfD8AUru7eJ26dYm1jnXJhOLdxTPLdheHdO0s5Z+3szRzD0hepfOA7pLOMNNl7cdal7U/
3QUSU+46oLuoK8N6Xl9yivDMy1t65p+927Go5hDHYr/NHIuZ8tmWPrFkGAWjYBTQFAAAzsNDVQ;

