-- HUMAN RESOURCE MACHINE PROGRAM --
-- 07-Zero-Exterminator - SIZE 13/4 - SPEED 12/23 --

-- This solution is level-specific (patterned and quantity-limited input).

    INBOX   
    OUTBOX  
    INBOX   
    INBOX   
    JUMPZ    a
    OUTBOX  
a:
    INBOX   
    OUTBOX  
    INBOX   
    INBOX   
    INBOX   
    JUMPZ    b
    OUTBOX  
b:
