-- HUMAN RESOURCE MACHINE PROGRAM --
-- 23-The-Littlest-Number - SIZE 24/13 - SPEED 67/75 --

-- This solution is level-specific (patterned and quantity-limited input).

    JUMP     b
a:
    COPYFROM 0
    OUTBOX  
b:
    INBOX   
    JUMP     d
c:
    ADD      0
d:
    COPYTO   0
    INBOX   
    JUMPZ    a
    SUB      0
    JUMPN    c
    INBOX   
    JUMPZ    a
    SUB      0
    JUMPN    c
    INBOX   
    JUMPZ    a
    SUB      0
    JUMPN    c
    INBOX   
    JUMPZ    a
    SUB      0
    JUMPN    c
    JUMP     a


DEFINE LABEL 0
eJzTYmBg2G45PTXYoqPd1mzCzC5Tk22GpkW7bpg4b2cAy23vOmwV2eJpv67ivHN/2S0X6YZbLknTNFyy
VoDkb7kc6/Z0t2oS8npb0+u7r/Jo0LqKppC3Nc9DK9q8w6+vB6l5kbqvsj/VefvdlBmrQfy7KRY2INqv
vKDEr3zDPgg7aGpBlXbj69p9lYwN+yoLm3jqrzZXtK1s11lS1CW6hWEUjIJRQBMAAL6oQ9M;

