-- HUMAN RESOURCE MACHINE PROGRAM --
-- 25-Cumulative-Countdown - SIZE 50/12 - SPEED 68/82 --

 -- Unrolled 11.79-skwasjer.asm

    INBOX   
    JUMPZ    k
    COPYTO   1
    COPYTO   0
    BUMPDN   1
    JUMPZ    a
    ADD      0
    COPYTO   0
    BUMPDN   1
    JUMPZ    d
    ADD      0
    COPYTO   0
    BUMPDN   1
    JUMPZ    b
    ADD      0
    COPYTO   0
    BUMPDN   1
    JUMPZ    c
    ADD      0
    JUMP     m
a:
b:
c:
d:
e:
f:
g:
h:
i:
j:
    COPYFROM 0
k:
l:
    OUTBOX  
    INBOX   
    JUMPZ    l
    COPYTO   1
m:
n:
    COPYTO   0
    BUMPDN   1
    JUMPZ    e
    ADD      0
    COPYTO   0
    BUMPDN   1
    JUMPZ    h
    ADD      0
    COPYTO   0
    BUMPDN   1
    JUMPZ    f
    ADD      0
    COPYTO   0
    BUMPDN   1
    JUMPZ    g
    ADD      0
    COPYTO   0
    BUMPDN   1
    JUMPZ    i
    ADD      0
    COPYTO   0
    BUMPDN   1
    JUMPZ    j
    ADD      0
    JUMP     n





