-- HUMAN RESOURCE MACHINE PROGRAM --
-- 38-Digit-Exploder - SIZE 29/30 - SPEED 199/167 --

    JUMP     f
a:
    COPYFROM 0
    OUTBOX  
b:
c:
    COPYFROM 3
    SUB      10
    JUMPN    d
    COPYTO   3
    BUMPUP   1
    JUMP     c
d:
    COPYFROM 1
    OUTBOX  
e:
    COPYFROM 3
    OUTBOX  
f:
    COPYFROM 9
    COPYTO   0
    COPYTO   1
    INBOX   
    COPYTO   3
    SUB      10
    JUMPN    e
    COPYFROM 3
    SUB      11
    JUMPN    b
g:
    COPYTO   3
    BUMPUP   0
    COPYFROM 3
    SUB      11
    JUMPN    a
    JUMP     g


DEFINE LABEL 0
eJwTZWBgWB4hqScWabIGyGSQi9kYzpwbHyZcfCBwV7GMP0hMuPiihlnRj/rcopqNIH7k5PTS9V23urU7
T09s7fi4ZFZn4/o9HTUba1rPbSqsKtrKMApGwSgYMgAAgYYgmg;

DEFINE LABEL 1
eJwTYWBgUErR9tydFlHdk+l6HMhl2Bl40706+YVjdo+cTn57sCVI7On0H/XLpkxv+T5Bvb9jQsmkqxP/
z9OaJrYjcRrTAZdJXkcX9cw4YdHueJJhFIyCUTCkAAAcGiIh;

DEFINE LABEL 3
eJyTYWBg2JfnaTsnf1uobv6bZUAuw7e8zSYcGVc8rybFh72Pm5IMEhNNe7NMs2Tq8saGWUtB/Adzgi0P
z3js/HT67mDZGYExmTOnJM+ZJ1X0cv6WiogFCxs2zr/au3LO1OXbZl3esHDmuU3NU89tujqxcT3DKBgF
o2BQAQCDKDUw;

DEFINE LABEL 9
eJzjZ2BgEMie5pBQstSKqcrPevdUGf/dU1NCTkz+H2Xdb5vyo1mg7FSlTm9paeAC4eI3y3YVT1j5qP/u
Grfl+3cwjIJRMAqGPAAAewsbrw;

DEFINE LABEL 10
eJzjZmBg2FUsFOxccLV3Tn7jeiCXgSd5d3Bi+lH/puLz3nUVTR5rmgzcJ7U9dmYYBaNgFAw7AACQkRD5
;

DEFINE LABEL 11
eJzjY2BgSEzXy1qY5dW4LVt4+rbsmo2xOez7gMIMp3MMu2XKejt2Nng1vprEXQESW9STEtLbrb+OYRSM
glEwLAAAl0IUZA;

