-- HUMAN RESOURCE MACHINE PROGRAM --
-- 22-Fibonacci-Visitor - SIZE 17/19 - SPEED 148/156 --

-- This solution is superseded by 16.126-skwasjer.asm being funcitonally same
-- with further optimization.

a:
    INBOX   
    COPYTO   2
    COPYFROM 9
    COPYTO   0
    COPYTO   1
    BUMPUP   1
b:
    OUTBOX  
    COPYFROM 0
    ADD      1
    COPYTO   1
    SUB      0
    COPYTO   0
    COPYFROM 2
    SUB      1
    JUMPN    a
    COPYFROM 1
    JUMP     b


DEFINE LABEL 2
eJwzZ2BgmKwtWqulLFq7WT6maaesWmelbN2sbXInF+kqTV55SXv2+hP6MRuAyhgW2Uo26Fi5L1xl9XnS
UhvFtvl20+v4XEVrj3jMbnTwet3j4PVnRpPn0flNngxzTP2WtGsHSTbMCZ9eNyVqdiNv7Ioun1jrGRei
eZeCzHqRNb/lRZbRpJxMwRUf0pdstUphOWuTzHFhX1LT6b9JmTutUqav2ZbKMn91pl7//dznndcLnnd2
lOn1O1eYTW2u6Fp8vOzaau/SW+smF8VseJQjuW5ZtujqFVkQs1826u1d2rxhH8MoGAWjgCAAANC3YSk;

