-- HUMAN RESOURCE MACHINE PROGRAM --
-- 40-Prime-Factory - SIZE 28/28 - SPEED 273/399 --
-- Based on 23.474-IAmWave.asm.

a:
    COPYFROM 24
    COPYTO   5
    BUMPUP   5
    INBOX   
    COPYTO   0
    COPYTO   1
    COMMENT  0
b:
    BUMPUP   5
c:
    COPYFROM 5
    SUB      1
    JUMPN    d
    COMMENT  3
    COPYFROM 0
    OUTBOX  
    JUMP     a
d:
    COPYFROM 24
    COPYTO   1
    COPYFROM 0
e:
    SUB      5
    COMMENT  1
    JUMPN    b
    JUMPZ    f
    COPYTO   2
    BUMPUP   1
    COPYFROM 2
    JUMP     e
f:
    COMMENT  2
    COPYFROM 5
    OUTBOX  
    BUMPUP   1
    COPYTO   0
    JUMP     c


DEFINE COMMENT 0
eJyrZmBgaOMNmqrLG1ikyzujYxLf+tmT+Ip23ecV3dLGe25uG++1Hgu+zNYowYKSQmGnwnZRp8Lv4gUl
aVJ3q1VktnfVyhxfd1paZWuh9IyOazJ/agMV+ssklQtKOlX7ywI1/tSyaL6dv02zcuU2zYV7gVYx7HBk
zv1t/yTLyPZJ1mEr5lxbs4ZSNZNrPfUmvItszSpXbrfcsbbbdsfaRfZZK3Y47p+T5eQ8Jcupv0zQyarp
sNPyTmPX/XMWu1euXOcxYzXIvDsh88tnhj3t9Q7PWvEpTHQLSCwnaJoTiFZINtm2O7Fxxu7EwKLdiVZN
eUnXevKSKtq0U/rLHNOcCjdmKOdfzjYqMM9NLJ6dd7eaoWB5J3ehylaQXqve/XM6elgm1Hb/Mpfs2qII
Ersx+2iGzdxlaUHzl6VtX3A049DCJ1k3F/eXGS152nt2UdK07QsWzKqfvWDWz2kiE92mHeueMrW/7Oc0
p8Izs45mgPRnb9SKm7FVKvb27owk731Psv7ucyoM21/R1rvnaa/m7q99dltFJq5dzzLBbu32LqM1Xs03
VwcW2a39ks22YVs6SH//Gebc5Avey45ffLbh+EWbE5WX2K6BxM3OVCS3nN4b1n9mbWjL5b1hEde5Y/Jv
ZiRdviWcJ3ZzXcXLK9qNXBesmhhGwSjAAgDrhtxG;

DEFINE COMMENT 1
eJxrYWBgSOVKmsbN9bZmOceyNG4ur+aT3CwTxLmPdYtzOxWe5L6aWc2zLK2Nd3pqqlB7ylWRJ1nfxe9W
80ot79wvVTgdqJ3htPL01EANrTgpbanYqXpSsSyGEYklxsy5aiY89WomkS3bDWd0dOke6+bXOtb9Vm1G
xwGlgpIDSkcz6lTaU0D6Dzvtq2RzvBMBYhu7asUtsueOUbeRigXxZZxFJso4n60CsZtjpqeKRB3N4IgU
zlsf0V+2PuJP7cXor30+8caTkxJZJogmbe/KS2oo5UxkzuVMXJZWmTy/fGPG016Q3nltE2ZatR7rbm85
WyXRND11S0NCwJaGrS56LbdNeTvnGqp0zzV82xthB1L7pvVohn/9sjQQm3/mtvTOKcvSiicJ552ZZNXU
OeVY9+rpzlOkZjlPMZzztc9mbmarzdz+MsM5RgWGc+aX28y9W12yaEaH0RKRibZLjSeDzHi6paJt7fqO
dqM1Vk3qq3nqs1YmFmetXJZ2c7VnwqJ13DFsG7hjZmy9mvlxq3AeSP3zI29rtA63p2gd/h0F4m847pkQ
tj8iEcSuvDQvhOtGfqDO7TeRznevZjrfTSy+fMuqKflGR/uEKxVtohfvVoefdyrceD4isfKSZTxID8+L
htKo5+0pc5/2BfO8UM4veDm//ORL7Ubxl0+ylF9FJFq+eRO58t3a0Iefz4YzjIIRBwDTMtna;

DEFINE COMMENT 2
eJwLYWBg8LRfuNfW7tmGTCvL+EwrJZ9z1ltdbO0i7LKcJK1uuUTYhXokBACVMax1eNrraf+1D8TOjeKp
T4q8W70k/GyVcNDZqj/+f2qf+Wa2nvcWmSjr/Xb+eW/rpV7+x9cJBz3b8Dz0+vq/4Z2rdkfyLjoWNaPj
WFTSNMe4bxtB5twvWbEmpfDZhpe5zzZUZR9fl5xZuXJ22v45/anGk/tTM1sd03jqN2Y0lFZlBxbNzgss
Wp6fWJxf9KcWpDe64/r6gPaCEhD7YY90Q02zdINLnVUTiM8/8271jdmJxawLjArqFxeULFz2tkZw5YyO
wyuNJ7OuuDfPY5n10vrFM1b/nHd8ndrs4+tYZlSuXDCNd5HbNJYJq6ffrZaata4CZI7d1uPrjLcUTjfe
sq+ycXNgEUjszzaWCX+2XesR2unVrLn7T23Y/vnliQfWVew6cLeaYRSMgiEGAJZmmJs;

DEFINE COMMENT 3
eJxzZmBg6LbdV7ndcn65oem6ikNGd6uDDLya3+ktmLVAX2ZxrGHnqnqTZxs8zEW3nLMW3WJrt2Ptb3vr
pTscj3UfdrriVua81BloBMNHP6umP/7ajcJB+yqbQvrLRKL6y+7EnK36HJfZ6hNfOP1FrMzi3KgVa9ZH
HF+XGHh8nZf/ijW3ff4uaPJRnvTMd0bH+gCeerngtzUgs05k3ZuXl3Wtpyq7oORytnSDYvbxdYrZfxdc
zg6a6pRn1RRZcLf6a9m+Sp5KnnrxqsxW8aoda0H60joLpzNPKJwuOelaj+Qkr+atE+5W13YnFvN2FpSs
bJ9frtfi1azcbDxZuXn/nO9tK9akdV5fv3XCsw2Sk66vr5s8YzXDKBgFIxAAAIdFfOU;

DEFINE LABEL 0
eJyTYGBgmOE3cc8Mv+1di/3f1oQGGPruCpS0Eg5S1ARKMQgHzQuRCzb0rYi+beoTv9boS9oe49YcC5vZ
eVtd/PIfuzMUrA1lKLia6ZR3bu6EXOulE3KfbWjNmbinNUf2mE7Ou0MMo2AUjIJBDQDCnydN;

DEFINE LABEL 1
eJzTZ2BgWOwetfyDW9I0T/f+sqeue8OAQgye7l+yZb09E+z9fkeFBtyJkAu+EzEzjDsmLKIi+ViUdqN8
tM4SkDrfdLmXE3I37NtbqDyJp9Iy/kGNh61/vYP2/sYlCjXNP0WUm08LFjZxioHUWk998MRgitj1zikb
9vFNfNq7dUJg0fw+7pgffXciiiflB/6c5ugnNcvRz31efqDa4jeR05ZWJP9aFli0cFlma/1ikYmZC52n
/JwXNHXbjKCpj6awTGAYBaNgFFAMAGxnUHc;

DEFINE LABEL 2
eJwLYGBgCJDwXuYirjzptdjd6u/i19evlJgw87S0VdND2bc1Kirzy6eo7atcpWHVtE3za982zXvzDmpV
rgRqY9BwmTDzvPO+ykYX48l2bjKL7dw6Vz11dZ7C7mnVVOb9p3ax/9kqueCKtqYQmcV3QrZ39YVGtuRG
ravwie8v250o3XApOWsFyJzZefPLq4qdCr+WORXyVDaUnqx6W3OlOrO1utp5ysmqCTNflcosZih4O392
3v45OjnKky5nWzXNzltXEVkwvxykv6NHOT+6w6jgavPd6qvNma0PWownu7YtmHW6y3qpfo/3sh993sv4
JvIuOjDx3NziSW9rtk6ISIyZoKgJ0vt0zYMn6qvvH2xYrZxvtOZLdvyGoxmNm49m/Nn2JTt7p1FB7x6r
pt49He2au7/2se9wntK4uXA624bC6TdXG09+ukZ5EsMQBg1b7HPdNkXUJ2/e22S3Va/fe4/kdJB402l3
ceXTt1RST8mqK5/ea3vk1ApXtlM8nkdOWQfPP6MWHXt2Z8bD0035889E1Eufu9csfDFmpuu1+bN33rKe
IXH72hSQGfsPuMfsP/Ao4uehg+EvTxwMVz7NEmVwSS26/HZMyMD6ehSgAwD0j9Bf;

DEFINE LABEL 5
eJwTZGBgWJ6fffpLXtEup7yIxAm5fcFOeQ7aKYVM6vdLmNSvVJ8x+VZX7hDV8NmDt1Eq1r9+emp7zZds
xorAovslicX5RU6FDKNgFIyCIQsAlI0cfw;

DEFINE LABEL 24
eJyTZWBgWJYe2fIlzajgS1pF8rJ0qVjF7AB/i9LXZuJVeXpz6/L0JrfeNj3QOc1Jv8fQ90ff0YwffbyL
JLtsTri27bgwqdb0JmOF6c38IrZrfvkrz+vk/DvMlbljLVdm4fQ9mTM6TmRZNQGtYPiSd339lgajggOd
a0MZRsEoGAWDBgAAeKs0fA;

