-- HUMAN RESOURCE MACHINE PROGRAM --
-- 20-Multiplication-Workshop - SIZE 46/15 - SPEED 73/109 --

    COMMENT  0
    BUMPUP   9
    BUMPUP   9
    ADD      9
    COPYTO   6
    ADD      6
    COPYTO   5
a:
b:
    COMMENT  1
    INBOX   
    JUMPZ    q
    COPYTO   0
    INBOX   
    JUMPZ    p
    SUB      5
    JUMPN    c
    JUMPZ    h
    COPYFROM 0
    JUMP     g
c:
    ADD      6
    JUMPZ    l
    JUMPN    e
    SUB      9
    JUMPZ    j
    JUMPN    d
    COPYFROM 0
    JUMP     i
d:
    COPYFROM 0
    JUMP     k
e:
    ADD      9
    JUMPZ    n
    JUMPN    f
    COPYFROM 0
    JUMP     m
f:
    COPYFROM 0
    JUMP     o
    COMMENT  2
g:
h:
    ADD      0
    ADD      0
i:
j:
    ADD      0
    ADD      0
k:
l:
    ADD      0
    ADD      0
m:
n:
    ADD      0
    ADD      0
o:
p:
    OUTBOX  
    JUMP     a
q:
    OUTBOX  
    INBOX   
    JUMP     b


DEFINE COMMENT 0
eJwLZmBgmClYd+KcKMcFK9mTF25olh26pP1+b5+u0pY+XZb5ItqfJ8WpZ3anq6h1Okk97/QVW9I+Xeha
bRa3Ucp6zkcR6zmnB6zh6nI3Uuhyf6101hNoHMN8O7Op98LMpsqGG01aEiLbnB/AUbLdt63Iwcu9WM8y
oXWT+eueT+ZV09dacixSsZVcd8f+8RZfV729H/23HFQI23JwXtiGfSBzPqWl6GxI32Gln3F0vlbW/E2K
uXp7ZfI/H2CsZDj1s7ruxPca62Nba1/vAqnliC9M/pv0OeVV5p+su3l7s0FiCa3vE6PaL1W59rsvtJ00
eWXODMl1KbMj1j6Yw7Eocv7sRvEFG5JA6rauUYt+v66/Yu36yStfbSjcv3rD53cg8RUbnQvmbi1N49z7
Oq724Jp4i8NGKV+O1OUYHLvVYHDsx9Sio0fn7zkouIJnz/Q1Ohsk1zGMglEwBAEAr6uW2g;

DEFINE COMMENT 1
eJwLZmBgmCn44/BEEY4L3OIBV+ulp9/KV5x9d4HarTtfzDguLLWxP6liW3X0iU3mzldW11YXWHAsOmBU
Nd1Hb8vkxaqfJzFLWc+YKPIHiJ938ortzHCXkAyyl66z2yn73XK10hZzHr1SCzvjvbZAaxj2ex10qPeq
m1XrfW/jdt8N+9YHmB9WDak6Khu+84hUxJaDUhGZO0HqBF1OlqwP4CgBsT+l9VfMKGDI6y79k/Wnam+2
ZQ1D3vr6kJq1DUvaXzbWzXrZuGb30mbeyyC1W2tPLppcFLIqskByXWJu7p7EXIZT4oUnLwgW+1zKbjwH
VuPav/PIkf57G0/2Ws/o6nUuAIk1Tfg8qWiaYNXj2dZZsvNK004v+Z4OElfZnKm/aLNef/S2a6sFd/05
dmZ327lTezguHNnnfj7jZOH++DNq20Hqfq2a33J+160GhlEwCoYgAAB3QJVH;

DEFINE COMMENT 2
eJwLYWBgENc66TZbY3qAuVxT/kGp6XW+YueW8orp7QVKMTzkmx0cJfg+cYqwddZBqZCaF8q5fTYm55bu
ML204ovZrXUgNXVJ0wMOJM4Pc0q0zjqccG8jSKzU75r/pzRBH/HCSz4gfm2Ve/GX2j9ZhvXWWW8arLMW
tbAUSnR0LZboEF0Nkn/SrNdfUfNnxtFy7yUdZddWe5bdWne0fPb6Nw2z14PkmSewODNP8F7SNGH6GhC/
fEpb0YdpdTkvZu7MiJ/7Pf32POssoUVdpfyLJ1efXSzbfHZxZjf/4tIp4gvcF8rPDVieNXP6GqNpt9bZ
TpIEu9lk7Wez4rWfJ+mvh/An7dTqcdv3vPPNcbVOhTP3mrVPnCwxO1KX43CgKrN1358sj711OZd2nisX
2XmrQWSn87xJOwVXTNh1ax3n3sTNzvsfb5lyYcnW/kvzNzGMglEwxAAAfMiWZQ;

DEFINE LABEL 0
eJwTZmBgiIrgvewVd2udfVLhxLcZt4K0slicX2Sp6cblVfLeyncX5yy7F8pYaZ1lWRNQqdB6bfWZnoOn
gNoYdiev6c3JNJp0tNxo0v/KDRMYhhgI3eu0c6DdMApGwUADAIlWIYA;

DEFINE LABEL 4
eJyTY2Bg2JBufawsVXLdttQ+GSCXYVvqWWnBYkG5hkpRRe1GRa2lzZn6D1sKTRVa99qmNvN4rmoM8dte
kxD+NsM6qzLlaOHXVPfin9UcJfdaQ2rEOm81BHXdaxboXtMb1GU9Q7rde0lCa8DyrbW31okUKW2RyVfb
npn1+QDDKBgFo2BQAAASGjJG;

DEFINE LABEL 5
eJyTZWBgUKpWVrqVz61slGSg3Ra/TX9RnI1JUex2p32xh72zEtrDu9LDc8IK1Ru96tNmCzUKrljV+HZT
VcOSrWoF3dvqksw2FMVqLl8VfXmBXtS0mf8iLvdOi1RvvBUjXeGXeLfgW1514qnSKr91Zbbu68pyjZ6V
VGowjIJRMAoGDQAATFYyuQ;

DEFINE LABEL 6
eJzjZ2BgeJW5Ui0qrc1lUopa9K9kqdRJKdIVUZXSFV71KaXfGpnS+praw/uaDOxWNdqYCDW2Ggo18sbs
a9baxTBIQOyke80PJ/D2PZzweO6/idPXTJ/is3vNDPPDO+bfO6GzZO/xo8vMDz9avmGf4wqjlWnLrGfM
nida+2yWd5nwNO8yiykbKv9NvNc80H4YBaNgoAAA+Cc+Kg;

DEFINE LABEL 9
eJyTYGBgUM9WjFicc9bzeoGZZUPlfI03DZIq1zrma3j0vTe2neTsZDWZx9Nq8qOII/32uVHtmd3JLZ8n
OVecW+qU+HqXe/yGfe7x5odZE6yPNSban1yXwXL2WgfHBYeJvJeV5nRfZBhC4OWJP1naJ5ryB9INYc85
dg6k/aNg5AEAZWYxnQ;

