-- HUMAN RESOURCE MACHINE PROGRAM --
-- 21-Zero-Terminated-Sum - SIZE 10/10 - SPEED 72/72 --

-- This solution is superseded by 10.68-skwasjer.asm being funcitonally same
-- with further optimization.

a:
    INBOX   
    JUMPZ    d
b:
    COPYTO   0
    INBOX   
    JUMPZ    c
    ADD      0
    JUMP     b
c:
    COPYFROM 0
d:
    OUTBOX  
    JUMP     a


DEFINE LABEL 0
eJyzZGBgMLSosr5lstdWxTDVWcVwsu8jw5iQvcbuMVOdtEoz3KsanngotjF6BUxg9Ho8V82jdDWn+5/1
ko5Ht2Vbcew8asCxk0nNftNXOaOVQKMY1lrmGs21F7X4GilqAeLXJbV1yicJrohMObotLTt3z4Ti/r0s
FRw751Ylbp5ae27pl9qI+us1GypBapUnXKpqmsDQmtr/Yypbf+6epgnXpsROMqu7OZmj5NuUJQVF05ry
s2Y25S+efbTw17zc8k8Lqxq6l/D2vVqyZfKrJbIb/68wq6te5V1WvJajZNNOs7pVe7ZMztj7fDvDKBgF
owAnAACaFWVA;

