-- HUMAN RESOURCE MACHINE PROGRAM --
-- 28-Three-Sort - SIZE 62/34 - SPEED 73/78 --

    COMMENT  11
a:
b:
c:
d:
e:
f:
    INBOX   
    COPYTO   0
    INBOX   
    COPYTO   1
    SUB      0
    JUMPN    i
    COMMENT  1
    INBOX   
    SUB      0
    JUMPN    h
    COMMENT  8
    ADD      0
    COPYTO   2
    SUB      1
    JUMPN    g
    COMMENT  10
    COPYFROM 0
    OUTBOX  
    COPYFROM 1
    OUTBOX  
    COPYFROM 2
    OUTBOX  
    JUMP     b
g:
    COMMENT  9
    COPYFROM 0
    OUTBOX  
    COPYFROM 2
    OUTBOX  
    COPYFROM 1
    OUTBOX  
    JUMP     c
h:
    COMMENT  7
    ADD      0
    OUTBOX  
    COPYFROM 0
    OUTBOX  
    COPYFROM 1
    OUTBOX  
    JUMP     f
    COMMENT  2
i:
    COMMENT  0
    INBOX   
    SUB      1
    JUMPN    k
    COMMENT  4
    ADD      1
    COPYTO   2
    SUB      0
    JUMPN    j
    COMMENT  5
    COPYFROM 1
    OUTBOX  
    COPYFROM 0
    OUTBOX  
    COPYFROM 2
    OUTBOX  
    JUMP     d
j:
    COMMENT  6
    COPYFROM 1
    OUTBOX  
    COPYFROM 2
    OUTBOX  
    COPYFROM 0
    OUTBOX  
    JUMP     a
k:
    COMMENT  3
    ADD      1
    OUTBOX  
    COPYFROM 1
    OUTBOX  
    COPYFROM 0
    OUTBOX  
    JUMP     e


DEFINE COMMENT 0
eJzTYWBgWM6jGJHBE+L3hNfaZj5/rtFNwT4ZAdFSLm7x79zHJPby/5aZrVoul6mfozQ/DKic4SW3kdlu
GSMzELtD/6TEASNvKRXbFJ1HtloGi2z1jB2NpgeA5D76t4kphDmL9MWwiDIl+ssyJd5TvxD92uBdgLXN
s+Amx3lhPJ73wqYH6AY+imh335B03bEwGaQvP8Bd3CDAX3anz3vjf15tLq4es4NB4rP+qkUzjIJRMAqo
CgAAGzfW;

DEFINE COMMENT 1
eJzTYGBg2MNiL5jBYy8Yz39UVFaARzpWYLrSEt7F2mbsz3WFRTL1z4kWmvKKfbcUEG1yfMg32VePSzKo
lF0yCKiVwYLtrLQFm7MTiL1S2V82RVVQ7o+xmWWD0V7bEO2zniDxaVqTfUH0fbsQP2bPDWy23t+5rX04
JKx91HT3eOsZ7/FucrT2aXMBqeF2s7Zx8DKzBLGn/tczZhgFo2AU0BQAAD5LJ8g;

DEFINE COMMENT 2
eJz7x8DAYGbmL8ulr6g1W+O75TKVPq9lKpN9b2mE+B016PP67KeoxZD0nbst3ozbxuSoc6OUddYT3sdt
S3jNpl4U2TnNRy+zOyZctNaw3r147tZHEZN23gqasT0icMfqW0Gb07pKJSKXtIdHFk48Wn50ft3Ko/NN
79TNev81t+/5j8dted+m172+fzBvx+rn0XfzIgIX2cqGPrLVirP15ig5Xzy52mW5ZEPQxdmNE172VzS/
Y8jrfv09ffGjFTFZJ/q8Eue0uUTnx4RwxMs2H4tfspWx0v2va/X//0DvMOgt+v//xNKmnyZrI24Xrsvc
eXbx5OpjfWc98zLcxc/bMkDBpt27WD8f0A0sO2SSdm3102zneU+zf0zVz3je6ZIwu/FZ8OO2/IAtk18G
nVwEUi2fpxihGiLok2B30u2qFo/nZvnpAfukFSO+yq2IaTPIjJV2SAjf4tfntSSkzm5e2GJt5VBJlfUB
7uKuHpW8XuYwO/tVzdhLuRgYJqhA+DbyzkxNwieZIbwmJhDOZMyH8s3YGRiqWPfyMzAEaUNEJE3VeO0F
ZQVyWViYGBwYGHa6QMTP2+xnztR35oPwlIH0P2ZRRQaGi1B9H6X/sLxndWA+KsrA8FoDIsbvoselqCUg
Wsq1RhwishRITxFuE8vlsrZhYNBMhIjuC1rPqaZ7AKpmliQDgwVblzsDw+doiMjxJF6xXKMpehCeiykD
A4+et1S/aG4CA0NPH0TUZMIbrqb8HKU+mS1QF3EB1Ydp7eX/LJ9rxMi8osuZ6X3/NzbZ5lUGEPlOIP1D
dj7QrdXJEJGoSBkxCGuZFANDAeclHwYG4UKISGveZeH3xi2Sl+SCRIzM3nDNDr4pWGd3Uny26kU5iIoN
wND4KndSIkXViu+MFkSsEUi7Sp6Vvim4WFuDZ6/tF/bpAX9YPqfsZ+4q/cPSVTpF+KQbq+QaQyep57ot
knrG6zmNUhgY1ldCdMeUf2HfkOQukWt0VA0i8hYYq6fFPpsp880OZmD4VAUR3dHZLxoTwm4P4Yn7MzDc
sY9RE9eaH8bAsG0ZRDS1RUZjvsZFawiPCegzVw8z7jKzz2brFD8D7fw2GyIT3rhM5bXBFkcIzxsYC9Md
GYSaDc0sbwuE1DAwcM6EyFi2P+MpTWOQPul2S2OxtqPRWekNFpW8e40lVSI1OdwapY4WMiABALUlMoE;

DEFINE COMMENT 3
eJwzZWBgKOCcH/aMx8xSVPio6EQRd/HdMvb22+S04oBSDIv4WJw3KrA4g9gTdK4pbrB4pPXG8rXBUYNb
QX66atEg8X4XDokpUe7iHPEnJdriz0onheYaffPdYbXTh8FBNpzBISSqzi4kisdTIUw2dKP/6zhb7w1J
oU6laSC9rR6zVQ96LtZm9Fpj6Ow5PQAkdr1gupJZ7Xtj+bxHESB+1WQe6X8Tz0pHtafoKLeUWjxpdnZK
bvH2iG2b7CvQPTu4ZlJMyLYpEYEgtWL/n+syjIJRMAqIBgB9TETo;

DEFINE COMMENT 4
eJwLZGBgMObg8TTg1DNeznNS4poAAxi8EmRgaJdQ1GqR3GCyW+asJ0hsE8di7ZPij7RA7GlaR0Un6BwV
dTE8K21p6i8baz9bdb5dguYXMz3jP8Zmlv+N9tqC1OUHFLK3JGxgY0gy47ZPOijUksAhMS1SVNE9PkLZ
JllW3SpFy6AmudCUKbHS+l6Yt4d2EA/YrpVBVnyqISclFMI+m4H4u2VOlkwRPlnykC+kZjlPTNNL7tIp
GTx1s57wui8UFb60ol0iZJWRwuSVILV1xk35epbOBfVe/RW23pOr/3lNr9tgwbEI7O7IDUn7ktbEb0hf
E78ia0PSi6y92TmZ7sWNibMbP6SndrzKXNP7KrNw4of0PzPsk9wXdsZ5L0kP5l0K0hseuSVVNGpnxuWo
kyWXo35MBYnd/GttwzAKRsEQBgDb4XFe;

DEFINE COMMENT 5
eJyzY2BguCzsLv6Et00sl6tLsoAzRKGAc42hHlednTZ3m0sq71nPcCFRf27xa/6NUiF+QOUMT1XcxWU0
3MX/GEuqFFjEqH0yV9SqM8416tC3t+/Wc3ft0z3pBlJ3xSkhPMCly73VY7F2kf9BodzAkxK3w3dYXY66
FwqSZ/Y86BAfdtBhWmSdHYi/L8ld/EcKh8St/AjlQxXzNQ5VPNc9Wq5nrJjb5wWS12zayx/UtYPHaYIV
387JB4VKpp6UMJp2TbF8ymLtSV0r9Dz6MvV/TzIy+zG5zm7fRA63iI57odqNCeEgvanNDELKLUdFF7Vc
U1za7O3BMApGwSgAAwDua1T3;

DEFINE COMMENT 6
eJwzYWBg+MNyK6iAM0FzEd9BoVgBd/HLwvfUe8Tq7P5Kv44DSjMYc7i7+oq5u4LYSmohCvy61xTv2+Ua
HTKUDQWJTYsMUXgWfE1xi5+iloXvCr0qn/fGVT57bdcEzg6eFpmb4JS4IQmkLifznnpt1WJtvYbXBvsr
+7y8S+eHBRaviZ9auCYeJC/c5SyybvpBofAFbWITF3lLCS2SVBFfoKilNXOLufgCa5urC+rsri5ocxFf
wOMpP1cyyGKKWvSxvsJkkN5jfYJytpNE/RlGwSgYBSQBALG9RkE;

DEFINE COMMENT 7
eJyzZ2BguMf/nZtZ6g/fZ/km4dVK7uIvlHmkl6lcklumMl/jhbKarqn8BhNmqUJTU/k/NkYKbS6FCn1e
2+RmB1fKzg/jkNCKy+XSSwQawzBTsE1sPv9e2/n8Ad4zBZdEgsRYJV8bXBQpNAWxLU39ZVVsZdUDXPSM
LzobmRlatLkcNbjmD5Kr8tGKexC6xXxa5HQloeijov4xHBKb0yIC12VsSALJPw456SYQc9azLonHE8RP
y76l4l36SMu4Ts/Yuvq7ZVwexJzfk9rEjvXxSF/rkFW/05ZrJNfm7HSnjcczoHuy75H+Sz4WU066gdTN
+ptrxDAKRsEoYAAAkjRR4A;

DEFINE COMMENT 8
eJxzY2BgWM/JI80tflKiUcpbap90n8xf6Qhle+kUHV6xDSYzBT+bMUvtsKqX/mNjK+PuWi8d4H1ONCZk
Oc+90O1sjyKA2hlWcQvKveQ+6gxiT9CZLM+lH6G8yVxR671Fio6epZbBJvPPZt9Nd1hN1u7zAqnhdnse
7eF+1rPKR1Llp0+fzBa/JuGP/oXs7wLes2YF8UgvD+5yB6lz8LK3L/K3tgGxT4qbTfUXLZwYK1A48Qmv
2dR3nCGrDDhX7FjPqbf3GU/ZIS9x+5P20nUnQGrZDTZMWGXFMEfNpm1Bg5HsRpAYn2vVUVvvtgW5gTFN
WUGzG58Fp3bEhx2cMy8sdw9I/qeP95LUEO8lIPb1fzEhDKNgFIwQAAACWl2E;

DEFINE COMMENT 9
eJxzYGBgyOBpE4sSZBD6oFAnkKPEIKSlzCKqpSwot1Fhvoa5XKb+X+lco5PiG0x2ym4wMZU3MiuRZ3He
JnfW86DUvVBhkczYAs4VMUBjGJT5TkrE83NIxAp0SUoIyYaCxPx0/WUdjQTlsq0kVVZYx6ip2Shqqdmo
6WZYZ+rbGTM4NBu6u4LU5QayiJ5xlVQJcFmsLejy3viM615bW+9r/gYBCeGqIQnh8WEQ83hjb6kci7+n
npadoqOY+9ogMfe98ae0Pzb2SRxuIPmzJSF+hyoy9f9Xhij8qRKUW9tQaf28qc/rTltqFEj+aHmf16Y6
Hk8Q+/o/M0uGUTAKRjgAAIuVS/8;

DEFINE COMMENT 10
eJyzZmBgOCnuLXVRhEf6I8d8jW9smfrb2TaYFHHU2WVx83jOERD1Z5CeHgBUxnBX/Z56pOY99TpjPeMV
1t8tV1gzOPw3CvEDyXG6n5Vu9fCWUg7lkQ6J8pcVip4sHxQ9W/VxSK7RxGhrG5/YJscTcSF+XnEJ4f4x
K2JmRuQmFPm/TwTptfZJ0Nzuq2WgGzjZVyP4UQRI7G3GYu1l2Sk6X2r/2HyvaXK8VBQTAhKXa8uMndNm
by/RMV9DuOukRH+3uzh3L4cERx+P9IdpQDfPFPRZNkstGqR2SieDw7YpBx1A7Dt/jMwYRsEoGAUYAABe
eU13;

DEFINE COMMENT 11
eJyzYWBgyFFydvqgwOJ8UOqav7/ohiQJoZMlMwWfd94U1Os/Lea9BCi++rO87Ma3irIbn6pcW52o1r9M
RsN53mwN6xkL1N73aylr9eyWyeyOEtwyGWgcw3+jNpcNFnV20Q5/bC46H3TgdnN3bfWICDzoGVDJ7Lmk
/Yyr9YwrTm0LbjqcXFRgwbHol8nemTYmpVPKzDK7V1k9bku2fdz2zdd+Nsgsvt3fLSsObzG/ee67Zf8l
I7N7Z7w9Ph4tTTu/S2kLSP7D3T827G+/Wzq+32tr98HZye4Dj2fb29nBmQ9K0zrefE+v/vi4zeaj0aQD
761nvL03fQ3DKBgFowAFAAAbNG4+;

DEFINE LABEL 0
eJzjZ2BgeJRz7nJkgd5entKd0wrqSy3eNOy1vdeqlzirfWdGT8/zzn0Tzy3Nn+58Rmtm/xWgcgb2cud5
fD1NcxlGwSgYBUMeAACrzxtW;

DEFINE LABEL 1
eJyTZ2BgWJZdaR2dv8X8fb2R2ZkeBgeHid4eFlNuBZVMTY36PLUpf8tUjpKdk6fXHetb0j6nbcOE9fWf
JwkWf570v/LzJL0Gs6m+PV2LW/qnr9k3ccWOfxML9zNPsD8p3HXyQkaTz6W0bN7LP1LczwOtYbhU5Owk
WPxj6tVCte2RBQdPMYyCUTAKBhwAAK7aPPU;

DEFINE LABEL 2
eJyTYGBg4OirtO7qNTIL6E7ReV9/UqKipk3saHmb2Ox8f1nz1EdabfGFptMijzo/C34UsTLoc8rKII4S
ici2BQxJDKc2p/FejsubfJ2xcvJ1w/pzlx+2OJ/h6NPadaR/ydZ/E0NWMYyCUTAKBjUAAI5fKy4;

DEFINE LABEL 3
eJwzZWBgyA08V17lw1Pu6ypYJeYUUS/pmNox3XFNr6CL9QwHL5b5L4O6FiuEXVoxJ/zeRtnwx1t++mw5
yOy580isfdXRDGv7k0AjGLziBKva4kVrGxM/T9LPYDiVlq20JSWnavrcvNQO8cINEyYX2c/2K1HawlJR
ddSx8s+x6mq9vZpNEfUgvfsmyjY7TDw6/0i/+WG2fudf7X0rnrn2919p6V+y9d/EulnfpqzoejZLtDZm
XkjNjfnXaicvnN3ov1itk3dJ4cTuJZdWzJw/f5PujCVbQWZtm5K5k2EUjIJRQDQAALLoYCY;

