-- HUMAN RESOURCE MACHINE PROGRAM --
-- 22-Fibonacci-Visitor - SIZE 175/19 - SPEED 52/156 --

    COMMENT  0
    BUMPUP   9
    COPYTO   8
    BUMPUP   8
    ADD      9
    COPYTO   7
    ADD      8
    COPYTO   6
    ADD      7
    COPYTO   5
    ADD      6
    COPYTO   4
    ADD      5
    COPYTO   3
    COMMENT  1
    COPYFROM 9
    OUTBOX  
    COPYFROM 9
    OUTBOX  
    INBOX   
    SUB      3
    JUMPN    a
    COPYFROM 8
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 6
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    COPYFROM 4
    OUTBOX  
    COPYFROM 3
    OUTBOX  
    COPYFROM 9
    OUTBOX  
    COPYFROM 9
    OUTBOX  
    INBOX   
    SUB      3
    JUMPN    d
    COPYFROM 8
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 6
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    COPYFROM 4
    OUTBOX  
    COPYFROM 3
    OUTBOX  
    INBOX   
a:
    ADD      3
    SUB      4
    JUMPN    b
    COPYFROM 8
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 6
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    COPYFROM 4
    OUTBOX  
    COPYFROM 9
    OUTBOX  
    COPYFROM 9
    OUTBOX  
    INBOX   
    SUB      3
    JUMPN    g
    COPYFROM 8
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 6
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    COPYFROM 4
    OUTBOX  
    COPYFROM 3
    OUTBOX  
    INBOX   
b:
    ADD      4
    SUB      5
    JUMPN    c
    COPYFROM 8
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 6
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    COPYFROM 9
    OUTBOX  
    COPYFROM 9
    OUTBOX  
    INBOX   
    SUB      3
    JUMPN    f
    COPYFROM 8
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 6
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    COPYFROM 4
    OUTBOX  
    COPYFROM 3
    OUTBOX  
    INBOX   
c:
    COPYFROM 8
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 6
    OUTBOX  
    COPYFROM 9
    OUTBOX  
    COPYFROM 9
    OUTBOX  
    INBOX   
    SUB      3
    JUMPN    e
    COPYFROM 8
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 6
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    COPYFROM 4
    OUTBOX  
    COPYFROM 3
    OUTBOX  
    INBOX   
d:
e:
f:
g:
    ADD      3
    SUB      4
    JUMPN    h
    COPYFROM 8
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 6
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    COPYFROM 4
    OUTBOX  
    INBOX   
h:
    ADD      4
    SUB      5
    JUMPN    i
    COPYFROM 8
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 6
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    INBOX   
i:
    COPYFROM 8
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 6
    OUTBOX  
    INBOX   


DEFINE COMMENT 0
eJzzZWBgWMKbEL6ElyFvEd/0ukV89rPnCDDkiQp/T+8X/ZzSIvk+8a90YfJvme/pP2S7SsvltHqAWhhS
VEP84tQv+diYXPIB8R+r/snaa/wnC8SWdCxMnuVQlTnLwWyqmNPsRj5XlsIut6b8Wu+m/G++XaWf/SZX
5wYenANSmxqSuu1GROJmENs93myqfdLnAyC2YHFEoGBxVebUQtlmEH9F1p8s+bzv6ROKS9Oqq0vTQGJX
Op9HX+msy4no0OoJ6uIo8egrTD444XWc7aTXcRZTCpONpjXlr5u+pB2k1nTqtdXrpl9brTTn3kYQn3fJ
0fndS3ZOY1+2ZfLflVsml62xn128NmB58drMnd9X/zj8dyXDqbZlbefalpUdalxRuL96VeH+vPVt515t
4LjAMApGwTACAAWaggk;

DEFINE COMMENT 1
eJwrZGBgMOaYfsuYI3Xbch4tgyW8kipLeJuEG6X6ZAJ1Zqtams5WBSphWMNVmlYvXZV5S6OrFMR/oPb5
wA3Nwv07THdOW2oj28zs2V/B6NVf0e4uWqtprdVjaLFlspnZ0flmZrfWbTW7t3G+XeLm6Y4Ra3tdj87n
dN8wgdNdsgGktt09dw/IPP8Ytc7LUUvak0LVOt8FGE2KCT84JzzSe8m1yJBV4ZGvdz0Oeb8XpE4+T894
Qe65pSD25rS6nMlF39NB7O4lK/TEF2gZ7Jnk7BTQHRMS0fE67mZ7aZr83L0zxRd4L5Gaf231vLn3NhpN
+3zAtf/PsYTWuhMgfde3W8+I3mY2tXjtzmnVq9wX1q08t7Ru5bXVZWtSt+Wtz9wJUuOx9/1ej73Ptx/Z
d2+j2ZFzS5ecsp+95vjBOVuOeC/ZdejWOutDqdt2HSrcv/1w2aH1x8oOrTpRuF/5dOLmhaed580/k7pt
/pmqoyBzGq/vnNZ4PXXbh7s7p+XcN5r04sGGCY8eGU269fTkorDnkHA4ecVDa+K1b/kgduxZw0DZS4zB
d69JBt18GOoGEpvz7qBQw/sXwSB2zXMVU45vn5QZRsEooAAAAMEEzlY;

