-- HUMAN RESOURCE MACHINE PROGRAM --
-- 30-String-Storage-Floor - Size 97/7 - Speed 85/203 --

-- This solution is an exploit discovered in 79.101.exploit-Otto42.asm.

    COPYFROM 12
    SUB      11
    COPYTO   24
    BUMPDN   24
    COPYFROM 4
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    COPYFROM 1
    OUTBOX  
    COPYFROM 7
    OUTBOX  
    COPYFROM 8
    OUTBOX  
    COPYFROM 9
    OUTBOX  
    COPYFROM 0
    OUTBOX  
    COPYFROM 1
    OUTBOX  
    COPYFROM 2
    OUTBOX  
    INBOX   
    INBOX   
    INBOX   
    INBOX   
    INBOX   
    SUB      24
    JUMPN    a
    JUMPZ    b
    JUMP     c
a:
    COPYFROM 22
    OUTBOX  
b:
    COPYFROM 22
    OUTBOX  
c:
    COPYFROM 22
    OUTBOX  
    COPYFROM 17
    OUTBOX  
    COPYFROM 18
    OUTBOX  
    COPYFROM 11
    OUTBOX  
    COPYFROM 12
    OUTBOX  
    COPYFROM 13
    OUTBOX  
    COPYFROM 14
    OUTBOX  
    COPYFROM 15
    OUTBOX  
    INBOX   
    INBOX   
    INBOX   
    SUB      24
    JUMPN    d
    JUMPZ    e
    JUMP     f
d:
    COPYFROM 22
    OUTBOX  
e:
    COPYFROM 22
    OUTBOX  
f:
    COPYFROM 22
    OUTBOX  
    COPYFROM 2
    OUTBOX  
    COPYFROM 13
    OUTBOX  
    COPYFROM 14
    OUTBOX  
    COPYFROM 15
    OUTBOX  
    COPYFROM 2
    OUTBOX  
    COPYFROM 5
    OUTBOX  
    COPYFROM 17
    OUTBOX  
    COPYFROM 18
    OUTBOX  
    INBOX   
    INBOX   
    INBOX   
    INBOX   
    INBOX   
    SUB      24
    JUMPN    g
    JUMPZ    h
    COPYFROM 22
    OUTBOX  
    INBOX   
g:
    COPYFROM 22
    OUTBOX  
h:
    COPYFROM 22
    OUTBOX  
    COPYFROM 22
    OUTBOX  


