-- HUMAN RESOURCE MACHINE PROGRAM --
-- 32-Inventory-Report - SIZE 13/16 - SPEED 53/393 --

-- Relies on a fixed floor where occurrences are: A=4, B=5, C=2, X=3

    BUMPUP   14
    BUMPUP   14
    ADD      14
    COPYTO   19
a:
    INBOX   
    SUB      4
b:
    JUMPN    c
    SUB      19
    JUMP     b
c:
    ADD      19
    ADD      14
    OUTBOX  
    JUMP     a


DEFINE LABEL 14
eJwTYWBgiCw46ylYvMPqbImRmVu5nnFt1Xtj47pSi1WN9vbKLd4eCq2SQYtatOKWN+3N3lQXUClYXDU9
Lq9/2a38SyvsqgKW76qevHJrbcyG3IbHWxhGwSgYBUMKAAC1dCLO;

DEFINE LABEL 19
eJwTYGBg2JFy1NkqZUmkfZJgFUNSaod9UumUmmTnedtSeZe+zZi8ckHupRXBRd5Laqt+TAUqZ/hTtTPD
rPbPjLUNDKcYRsEoGAVDGgAAU3Ybpw;

